(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    102150,       1783]*)
(*NotebookOutlinePosition[    150337,       3167]*)
(*  CellTagsIndexPosition[    150261,       3161]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Document Formatting Strategies", "Title"],

Cell[TextData[{
  "Andr\[EAcute] Kuzniarek",
  "\n",
  StyleBox[
  "Publications Production Manager\nElectronic Documents Manager\n", 
    "Subsubtitle",
    FontSlant->"Plain"],
  StyleBox["Publicon", "Subsubtitle"],
  StyleBox[" Project Manager", "Subsubtitle",
    FontSlant->"Plain"]
}], "Subtitle"],

Cell[TextData[StyleBox[
"http://www.wolfram.com/~andre/Demos.html\nandre@wolfram.com",
  FontSlant->"Plain"]], "Author",
  CellFrame->False,
  LineSpacing->{1, 8}],

Cell[CellGroupData[{

Cell["Style Sheet Arcana", "Section"],

Cell[CellGroupData[{

Cell["Concepts", "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " style sheets allow for complete control of the appearance and \
functionality of your notebooks. Limiting the application of cell formatting \
options through style sheets makes a notebook easy to maintain and enhances \
portability:"
}], "Text"],

Cell["Global editing control", "Item"],

Cell["Apply the same styles to many docs", "Item"],

Cell["\<\
Simplified document description preserves structure and allows for \
easy translation to other structured document descriptions such as \
SGML/XML/HTML and TeX\
\>", "Item"],

Cell["\<\
In some ways the front end obscures this important functionality \
because it offers so many menus full of choices for adding formatting \
description at the content level. It may seem like a back door approach to \
support document structure at the style sheet level, but it will pay off in \
the long term if you make a habit of it. \
\>", "Text"],

Cell[TextData[{
  "My argument is to promote ",
  StyleBox["structure", "BF"],
  " over ",
  StyleBox["stricture. ", "BF"],
  "I suggest taking that as far as using a new cell for every paragraph of \
your document, as I\[CloseCurlyQuote]ve done here. This is probably the \
hardest structural discipline to stick to, but it allows for global paragraph \
formatting changes and greater export control, etc."
}], "Text"],

Cell[TextData[{
  "Please note the detailed documentation for style sheets in the online help \
that was added to Version 3.0.1 \[LongDash] ",
  StyleBox["Help:OtherInfo:Style Sheets", "BF"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Let\[CloseCurlyQuote]s see what style sheets do"], "Subsection"],

Cell[TextData[{
  "Here\[CloseCurlyQuote]s a quick little demo of the way style sheets \
provide document formatting flexibility (borrowed from ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  "): ",
  ButtonBox["Style Demo",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "Style.nb"], None},
    ButtonStyle->"Hyperlink"],
  "\n\nThe document\[CloseCurlyQuote]s formatting description is in the style \
sheet, the structure is in the notebook itself."
}], "Text"],

Cell[TextData[{
  "Simplified cell structure using a cell ",
  StyleBox["style", "BF"],
  " at the document level:"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005900003Q000`40O003h00OogooBWoo000MOol3
0029Ool3000eOol3001POol20003Ool001eoo`03001oogoo08aoo`03001oogoo03Eoo`03001oogoo
01ioo`03001oogoo03eoo`03001oogoo005oo`000Woo0`0017oo0`000goo1@000Woo1@000Woo00<0
07ooOol02Woo10001Goo0`0017oo0`0017oo0P0000=oo`0000001`000Woo0`000Woo0`0000Aoo`00
000000=oo`8000Uoo`@000Eoo`<000=oo`@0009oo`L00006Ool00000001oo`0017oo0P001Goo0P00
0goo1@0000Eoo`00000007oo00<00003Ool00000008000Yoo`@000Eoo`8000=oo`@000=oo`<00003
Ool007oo00=oo`8000Aoo`<000=oo`@000=oo`D000=oo`<000=oo`@000aoo`03001oogoo015oo`<0
00=oo`D000Aoo`8000=oo`D000=oo`<000aoo`03001oogoo005oo`0000=oo`00Ool00Woo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00]oo`04001o
ogoo0003Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`03001oogoo0080009oo`05001o
o`00Ool00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`04001oogoo0009Ool00`00
Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol00goo00L007oo001oo`00Ool00003Ool00`00
Oomoo`02Ool01000Oomoo`000goo00@007ooOol000Aoo`03001oogoo009oo`07001oogooOol007oo
00000goo00<007ooOol027oo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00@007ooOol0009oo`07001oogooOol007oo00000goo00<007ooOol00goo
00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol0000POol00`00Oomoo`04Ool00`00
Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo005o
o`0000<007ooOol01Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
2goo00D007ooOomoo`00009oo`05001oogooOol00002Ool00`00Oomoo`04Ool01@00Oomoogoo0000
0Woo00D007oo001oo`00009oo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool0
0`00Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol00goo00L007oo001oo`00Ool00003Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01`00Oomoogoo001o
o`0000=oo`03001oogoo00aoo`05001oogooOol00006Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00eoo`03001oogoo005oo`0000<007ooOol01Goo1@0017oo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`00009oo`05001oogooOol00002Ool0
0`00Oomoo`04Ool01@00Oomoogoo00000Woo00D007oo001oo`00009oo`D0009oo`05001oogooOol0
0003Ool00`00Oomoo`0:Ool00`00Ool00004Ool01@00Oomoogoo00000goo00<007ooOol00goo00D0
07oo001oo`00009oo`@000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`07001o
ogooOol007oo00000goo00<007ooOol037oo00D007ooOomoo`0000Ioo`03001oogoo00=oo`@000Ao
o`03001oogoo00=oo`D00003Ool007oo009oo`03001oogoo00=oo`03001oogoo009oo`D000=oo`<0
025oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`D000]oo`03
001oogoo005oo`0000<007ooOol01Goo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00]oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
009oo`05001oogooOol00002Ool01@00Ool007oo00000Woo00D007ooOomoo`00009oo`80009oo`05
001oogooOol0000<Ool30004Ool01@00Oomoogoo00000goo0P0017oo00L007oo001oo`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02Ool20002Ool00`00
Ool00003Ool00`00Oomoo`09Ool30004Ool00`00Oomoo`04Ool20003Ool01@00Oomoogoo000017oo
00<007ooOol00goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00
Oomoogoo00000Woo00D007ooOomoo`00021oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`01Ool00003001oogoo00Ioo`<0
00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oo`0000=oo`05001oogoo
Ool00003Ool30004Ool30002Ool20002Ool200001Woo00000000Ool000Aoo`<0009oo`800003Ool0
000000=oo`@000Yoo`03001oo`0000Eoo`<000=oo`800004Ool00000Ool300000goo001oo`02Ool3
0004Ool40003Ool40003Ool30003Ool200000goo00000003Ool50009Ool00`00Oomoo`04Ool40003
Ool200000goo00000002Ool30004Ool40004Ool30003Ool50002Ool30005Ool30004Ool30004Ool0
0`00Ool0000BOol00`00Ool00002Ool01000Oomoo`000Woo00<007oo00000P0017oo10001Goo00<0
07ooOol00goo0`0017oo00<007oo00001Goo00<007ooOol00Goo00000goo001oo`02Ool00`00Oomo
o`09Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Ool00003Ool01000Oomo
o`00;Woo00<007ooOol02Woo00D007ooOomoo`0001moo`03001oogoo00Aoo`03001oogoo01moo`05
001oogooOol00003Ool00`00Oomoo`0BOol00`00Oomoo`0WOol00`00Ool0000BOol00`00Ool00002
Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol02Woo00<007oo0000
1Goo00<007ooOol00Goo0002Ool40009Ool30004Ool30004Ool30005Ool00`00Ool00002Ool4000_
Ool00`00Oomoo`09Ool6000OOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0HOol40003
Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Ool0000BOol00`00Ool00002
Ool70003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool3000<Ool00`00Ool00004Ool20003Ool00?mo
odYoo`00ogooBWoo003oOom:Ool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{329, 14},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Messy cell level ",
  StyleBox["description", "BF"],
  " at the same document level:"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000680000h1000`40O003h00OogooRGoo000[Ool3
001]Ool3001WOol20005Ool2001jOol002ioo`03001oogoo06Yoo`03001oogoo03eoo`03001oogoo
019oo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo07Qoo`003Woo1@000goo0`0000=oo`00
Ool00Woo0`000Woo0P000Woo0P000Woo10000goo100017oo0`0017oo0P0000=oo`0000000`0000Eo
o`00000007oo00D000moo`<0009oo`04001oogooOol30002Ool50004Ool30004Ool30003Ool50003
Ool30003Ool40003Ool00`00Oomoo`05Ool30004Ool00`00Oomoo`04Ool30003Ool50002Ool50003
Ool30003Ool50002Ool50004Ool00`00Oomoo`0:Ool30005Ool00`00Oomoo`0:Ool30005Ool00`00
Oomoo`04Ool00`00Oomoo`1hOol000moo`07001oogooOol007oo00000goo00D007ooOomoo`0000=o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00D007ooOomo
o`00009oo`03001oogoo0080009oo`07001oogooOol007oo00000goo00<007ooOol01goo0P001Woo
00@007ooOol000=oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009o
o`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00goo00<0
07ooOol017oo00D007ooOomoo`0000Uoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol0000@Ool01@00Oomo
ogoo000047oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo07Qoo`003goo00L007oo
Oomoo`00Ool00003Ool01@00Oomoogoo00001Woo00<007oo00000goo00D007ooOomoo`0000Aoo`03
001oogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool00003
Ool00`00Oomoo`09Ool20004Ool00`00Ool00003Ool00`00Oomoo`02Ool01000Oomoo`000goo00<0
07oo00001goo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool01@00Oomoogoo00002Goo00D007ooOomoo`0000Aoo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo015oo`05001oogooOol0
000@Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0N7oo000?Ool01@00Oomoogoo
00000Woo10000goo00<007ooOol017oo0P0017oo00D007ooOomoo`0000Aoo`03001oogoo00=oo`05
001oogooOol00002Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool00003Ool01000Oomoogoo
1@001Goo0P000Woo10000Woo00@007ooOomoo`<00003Ool007oo009oo`03001oo`0000Moo`05001o
ogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol0
17oo00D007ooOomoo`0000Uoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol047oo00D007ooOomoo`00011oo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`1hOol000moo`@0009oo`05001oogooOol00003
Ool01@00Oomoogoo00000Woo00<007oo00000goo00D007ooOomoo`0000Aoo`8000Aoo`05001oogoo
Ool00002Ool01@00Oomoogoo00000Woo0P000Woo00<007oo00000goo00<007ooOol02Goo0P0017oo
00L007ooOomoo`00Ool00007Ool40002Ool00`00Oomoo`05Ool01@00Oomoogoo000017oo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`8000Aoo`03001oogoo00Aoo`05001oogooOol0000:Ool30005
Ool00`00Oomoo`05Ool01000Oomoogoo10001Goo00<007ooOol01Goo00<007ooOol03goo00D007oo
Oomoo`00011oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`1hOol000moo`05001o
ogooOol00002Ool30005Ool30003Ool00`00Oomoo`020002Ool50002Ool200000goo00000003Ool3
0002Ool20002Ool2000017oo000007oo0P000goo10002Goo0P001Woo00L007ooOomoo`00Ool00007
Ool01`00Oomoogoo001oo`0000Qoo`<000Eoo`03001oogoo00=oo`<000=oo`800003Ool00000009o
o`03001oogoo00Aoo`05001oogooOol00009Ool01@00Oomoogoo00000Woo00<007oo000027oo00@0
07ooOol000Ioo`03001oo`0000Qoo`03001oogoo00ioo`05001oogooOol0000@Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007ooOol0N7oo000?Ool01@00Oomoogoo000047oo00<007ooOol0
:Woo00<007ooOol03goo00D007ooOomoo`00009oo`05001oogooOol00002Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000]oo`03001oogoo011oo`03001oogoo00Aoo`05001oogooOol00009Ool0
1@00Oomoogoo00000goo0P0017oo00D007ooOomoo`00009oo`03001oogoo00Eoo`8000Aoo`05001o
ogooOol0000@Ool01@00Oomoogoo000047oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001o
ogoo07Qoo`003Woo1@0047oo0P00:goo0P0047oo1@0017oo100000=oo`0000000`0017oo10002Goo
0`004Woo0`001Goo0`002goo0`001Goo00<007ooOol00goo0`000goo1@0017oo00<007ooOol00goo
0`004Woo0`004Woo0`0017oo0P001Goo0P00NWoo003oOon9Ool00?moohUoo`00ogooRGoo003oOon9
Ool0075oo`<002Moo`<000aoo`800=aoo`00LWoo00<007ooOol09Woo00<007ooOol03Goo00<007oo
Ool00goo00<007ooOol0e7oo000>Ool40005Ool30002Ool3000017oo000000000goo0P0017oo0`00
17oo0`000goo1@000goo0`000goo10004Woo0`000goo10000goo0`0000=oo`00Ool00goo00@007oo
Oomoo`H000=oo`<000Eoo`03001oogoo00=oo`<000=oo`D0009oo`03001oogoo00Aoo`D000Aoo`03
001oogoo00Aoo`03001oogoo0==oo`003goo00<007ooOol017oo00D007ooOomoo`00009oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol02Goo0P001Woo00D007ooOomoo`0000=oo`03
001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`3JOol000moo`03001oogoo00Aoo`05001oogooOol00002Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`0;Ool20003Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oo`0000=oo`05001oogooOol00002Ool00`00Oomo
o`05Ool00`00Ool00003Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`3JOol000moo`03001oo`0000Aoo`05001oogooOol00002Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`05
001oogooOol00003Ool00`00Oomoo`03Ool50005Ool200000goo001oo`02Ool30002Ool00`00Oomo
o`03Ool40004Ool00`00Ool00003Ool00`00Oomoo`04Ool50003Ool00`00Ool00003Ool50004Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`3JOol000moo`<000Aoo`05
001oogooOol00002Ool20002Ool01@00Oomoogoo000017oo00<007ooOol01Goo00D007ooOomoo`00
00Aoo`03001oogoo009oo`05001oogooOol00003Ool2000<Ool20003Ool00`00Oomoo`06Ool20003
Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`03001oogoo00Aoo`05001oogooOol00002
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo0=Yoo`003goo00<007oo00001Goo0`000Woo0P0000=oo`0000000goo
10000Woo00<007ooOol01Woo0`001Goo00<007ooOol00goo0`000goo0P0000=oo`00000027oo0P00
1Goo00<007ooOol01Goo0P0000=oo`0000000Woo0`000goo0`0000Ioo`00000007oo0007Ool30002
Ool3000017oo000000000Woo0`001Goo00<007ooOol00Woo00<007ooOol017oo00<007oo00001Woo
00<007ooOol0fWoo000?Ool01@00Oomoogoo00004Goo00<007ooOol00goo00D007ooOomoo`0000]o
o`03001oogoo01ioo`05001oogooOol0000GOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`00Oomo
o`05Ool20006Ool00`00Oomoo`3JOol000ioo`H0015oo`03001oogoo00Aoo`@000Uoo`<0025oo`@0
01Ioo`<001Yoo`<000Aoo`<000Ioo`03001oogoo00=oo`800=aoo`00ogooRGoo003oOon9Ool00?mo
ohUoo`00ogooRGoo003oOon9Ool006Aoo`03001oogoo0?moob9oo`003Woo10001Goo0`000Woo0`00
00Aoo`00000000=oo`8000=oo`@000=oo`D0009oo`D000=oo`<001=oo`<000=oo`<000Eoo`03001o
ogoo0?moob5oo`003goo00<007ooOol017oo00D007ooOomoo`00009oo`05001oogooOol00003Ool0
1000Oomoo`000Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00002Ool01@00
Oomoogoo000027oo0P002Goo00D007ooOomoo`0000=oo`03001oogoo0?moobIoo`003goo00<007oo
Ool017oo00D007ooOomoo`00009oo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool20007Ool01@00Oomoogoo00000goo
00<007ooOol0ogoo9Woo000?Ool00`00Ool00004Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`D0009oo`D0
00Eoo`80009oo`D0009oo`05001oogooOol0003oOolXOol000moo`<000Aoo`05001oogooOol00002
Ool20002Ool01@00Oomoogoo00001Woo0`001Goo00<007ooOol00Woo00@007ooOol000=oo`05001o
ogooOol0000:Ool20004Ool01000Oomoo`000goo00D007ooOomoo`000?moobQoo`003goo00<007oo
00001Goo0`000Woo0P0000=oo`0000000goo10000goo00<007ooOol017oo0`0017oo1@000goo0`00
2Goo0P001goo00<007oo00000goo00D007ooOomoo`000?moobQoo`003goo00D007ooOomoo`00015o
o`03001oogoo00=oo`05001oogooOol0000WOol20003Ool01@00Oomoogoo0000ogoo:7oo000>Ool6
000AOol00`00Oomoo`04Ool40004Ool00`00Oomoo`0QOol00`00Oomoo`02Ool3003oOolYOol00?mo
ohUoo`00ogooRGoo003oOon9Ool00?moohUoo`00<Goo0`008Goo0`005Goo00<007ooOol09Goo00<0
07ooOol0l7oo000bOol00`00Oomoo`0SOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0J
Ool00`00Oomoo`03Ool00`00Oomoo`3YOol000ioo`H0009oo`D00005Ool00000001oo`030002Ool3
0003Ool40003Ool40003Ool300000goo001oo`02Ool30003Ool500001Goo00000000Ool00`0000=o
o`0000000P004goo00<007ooOol00goo0`001Goo00<007ooOol02goo0`0017oo0`0017oo00<007oo
Ool017oo00<007ooOol0j7oo000?Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomo
o`00009oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool00003Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool0
0`00Oomoo`07Ool20008Ool00`00Oomoo`02Ool01@00Oomoogoo00004goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol0kgoo000?Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007oo
Oomoo`00009oo`03001oogoo00Qoo`04001oogoo0003Ool00`00Ool00003Ool01@00Oomoogoo0000
27oo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`09Ool20006Ool00`00Oomo
o`02Ool01@00Oomoogoo00004goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0kgoo000?
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo1@001Woo00@007ooOol000=o
o`03001oogoo00@000=oo`03001oogoo00Ioo`03001oogoo009oo`07001oogooOol007oo00000goo
00@007ooOomoo`D000Eoo`8000=oo`03001oogoo00=oo`05001oogooOol0000@Ool50002Ool50005
Ool00`00Oomoo`3^Ool000moo`03001oogoo00Ioo`03001oogoo009oo`80009oo`04001oogoo0003
Ool01000Oomoogoo0`000goo00L007ooOomoo`00Ool00003Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00<007ooOol00Woo0P000Woo00<007oo00000goo00<007ooOol02Goo0P001Woo00<007oo
Ool00Woo00D007ooOomoo`00011oo`04001oogoo0003Ool01000Oomoo`001Goo00<007ooOol0kgoo
000?Ool00`00Oomoo`04Ool30003Ool200000goo00000004Ool30003Ool00`00Oomoo`03Ool50003
Ool30005Ool30003Ool30003Ool200000goo00000003Ool50008Ool20008Ool00`00Oomoo`02Ool0
1@00Oomoogoo00004Goo00<007oo000017oo00<007oo00001Goo00<007ooOol0kgoo000?Ool00`00
Oomoo`0IOol01@00Oomoogoo0000?7oo00<007ooOol00Woo00D007ooOomoo`00019oo`8000Eoo`80
00Eoo`03001oogoo0>moo`003Woo0`001goo00<007ooOol04Goo10006Goo00<007ooOol08Goo00<0
07ooOol00Woo0`0057oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0l7oo003oOon9Ool0
0?moohUoo`00ogooRGoo003oOon9Ool00?moohUoo`00Qgoo00<007ooOol0oWoo000>Ool3000017oo
000000000Woo0P0000=oo`0000000goo0P0017oo0`000goo1@0000Eoo`00000007oo00<00003Ool0
000000<000=oo`<0009oo`<00004Ool000000003Ool2000@Ool40004Ool3000017oo001oogoo1@00
0Woo100017oo0`001Goo00<007ooOol0oGoo000?Ool01@00Oomoogoo00000Woo00<007ooOol00P00
0goo00@007ooOol0009oo`05001oogooOol00004Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00
00=oo`05001oogooOol00003Ool01000Oomoo`000goo00D007ooOomoo`00009oo`03001oogoo00Io
o`8000Ioo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`000?moo`Eoo`003goo1@000Woo00D007ooOomoo`0000=oo`03001oogoo00=o
o`05001oogooOol00004Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000=oo`05001oogooOol0
0006Ool01@00Oomoogoo00000goo00<007ooOol02goo0P0017oo00<007ooOol00goo00D007ooOomo
o`0000Eoo`03001oogoo00Ioo`04001oogoo003oOol9Ool0011oo`03001oo`0000=oo`05001oogoo
Ool00003Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00<007ooOol00Woo00L007ooOomoo`00
Ool00003Ool01000Oomoogoo1@000Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`D000Eoo`80
009oo`03001oo`0000Aoo`@000Eoo`03001oogoo00=oo`<000=oo`D00?moo`Eoo`0047oo00<007oo
00000goo00D007ooOomoo`0000=oo`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`02
Ool20002Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00P000Woo00D007ooOomo
o`0000eoo`8000Aoo`<000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`000?moo`Eoo`004Goo00@007ooOomoo`80009oo`80009oo`@000Aoo`<000Eo
o`04001oogooOol200000goo00000003Ool40004Ool30002Ool200000goo00000003Ool40009Ool2
0006Ool00`00Ool00004Ool30006Ool00`00Oomoo`03Ool30004Ool3003oOol6Ool0015oo`03001o
ogoo00Yoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo011oo`03001oogoo015oo`05001o
ogooOol0000;Ool00`00Oomoo`3oOolCOol0011oo`8000aoo`03001oogoo00Yoo`D000]oo`80019o
o`03001oogoo011oo`H000Uoo`<00?mooaEoo`00ogooRGoo003oOon9Ool00?moohUoo`00ogooRGoo
003oOon9Ool00:Yoo`03001oogoo0=]oo`003goo10000Woo0`0000Aoo`000000009oo`<000Aoo`03
001oo`0000Aoo`<000Aoo`<000=oo`D0009oo`D00003Ool0000000<000=oo`@000=oo`<00003Ool0
07oo009oo`<0009oo`80009oo`8000=oo`<000Eoo`80011oo`@000Aoo`<00004Ool007ooOol50002
Ool40004Ool30005Ool00`00Oomoo`3JOol000moo`05001oogooOol00002Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000=oo`03001oo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo009oo`05001o
ogooOol00003Ool01@00Oomoogoo00000Woo00@007ooOol000=oo`05001oogooOol00003Ool01000
Oomoo`0027oo0P001Woo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo009oo`05001o
ogooOol00002Ool01@00Oomoogoo0000hGoo000COol01000Oomoo`000goo00@007ooOol000=oo`0:
001oogoo001oo`00Ool007oo0007Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001o
o`0000Aoo`03001oogoo00Eoo`03001oogoo00]oo`8000Aoo`03001oogoo00=oo`05001oogooOol0
0005Ool00`00Oomoo`06Ool01000Oomoo`00iGoo000COol01000Oomoo`000goo00@007ooOol000=o
o`0:001oogoo001oo`00Ool007oo0007Ool50004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo00<007ooOol00goo10000goo00<007ooOol017oo0P001Goo1@000goo00<007oo
Ool00goo1@001Goo0P000Woo00<007oo000017oo10001Goo00<007ooOol00goo0`000goo1@00hGoo
000@Ool30003Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`07001oogooOol007oo0000
1goo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo009oo`@000Aoo`8000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000Woo00<007oo000017oo00D007ooOomoo`0000=oo`03001o
ogoo00]oo`8000Aoo`<000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`000>5oo`003goo00<007ooOol017oo100017oo0`000Woo0`0000=oo`000000
0P0027oo0`001Goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00009oo`800003Ool0
0000009oo`<000Eoo`<000=oo`03001oogoo008000=oo`<000=oo`@000Uoo`8000Ioo`03001oo`00
00Aoo`<000Ioo`03001oogoo00=oo`<000Aoo`<00>9oo`003goo00D007ooOomoo`00009oo`03001o
ogoo019oo`05001oogooOol0000;Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo0000
5goo00<007ooOol037oo00<007ooOol04Goo00D007ooOomoo`0000]oo`03001oogoo0>moo`0047oo
100000=oo`0000005Goo10002Goo0`0017oo0`000goo1@005goo0P003Woo00<007ooOol047oo1P00
2Goo0`00lGoo003oOon9Ool00?moohUoo`00ogooRGoo003oOon9Ool0041oo`<00?moodIoo`00@goo
00<007ooOol0B7oo00<007ooOol0mgoo000>Ool40005Ool30002Ool3000017oo000000000goo0P00
17oo00<007oo000017oo0`000goo1@000Woo10000Woo0`0000Aoo`00000000=oo`8001Moo`D000Ao
o`<000=oo`D0009oo`D000]oo`03001oogoo0?Ioo`003goo00<007ooOol017oo00D007ooOomoo`00
009oo`05001oogooOol00003Ool01000Oomoo`000goo00<007oo00000goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`03001oogoo00Io
o`8000eoo`05001oogooOol00002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03001o
ogoo0?moo`Aoo`003goo00<007ooOol017oo00D007ooOomoo`00009oo`05001oogooOol00003Ool0
0`00Oomoo`04Ool00`00Ool00003Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol0000=Ool2000;Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool00`00Oomoo`3oOol4Ool000moo`03001oo`0000Aoo`05001oogooOol0
0002Ool01@00Oomoogoo00000goo00<007ooOol00goo00D007oo001oo`00009oo`D000Aoo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`D000Eoo`8000Uoo`05001o
ogooOol00002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03001oogoo0?moo`Aoo`00
3goo0`0017oo00D007ooOomoo`00009oo`80009oo`05001oogooOol00005Ool01@00Ool007oo0000
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000eoo`8000]oo`@000=oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol0
ogoo17oo000?Ool00`00Ool00005Ool30002Ool200000goo00000003Ool40003Ool01@00Ool007oo
00000goo0`000goo0`0017oo1@000Woo10000goo10002Goo0P001goo00<007oo00000goo00D007oo
Oomoo`0000=oo`<000Eoo`03001oogoo009oo`@000Aoo`03001oo`000?ioo`003goo00D007ooOomo
o`00015oo`03001oogoo00=oo`05001oogooOol0000GOol00`00Oomoo`05Ool00`00Oomoo`0BOol0
0`00Ool00003Ool01@00Oomoogoo00002goo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000
oWoo000>Ool6000AOol00`00Oomoo`02Ool3000017oo000000002Woo00<007ooOol027oo0P001goo
00<007ooOol04Woo00<007oo00000Woo1@002Woo0`001Woo0P0017oo00<007oo0000oWoo003oOon9
Ool00?moohUoo`00ogooRGoo003oOon9Ool004ioo`<00?moocQoo`00Cgoo00<007ooOol0Ggoo00<0
07ooOol0e7oo000>Ool40005Ool30002Ool3000017oo000000000goo0P000Woo100017oo0`0000=o
o`00Ool01`0000=oo`0000000`000Woo1@0017oo00<007ooOol05Woo0`0000Aoo`000000009oo`<0
00=oo`D000Aoo`03001oogoo00=oo`<000Eoo`8000=oo`D000=oo`<000=oo`<00003Ool007oo00Yo
o`03001oogoo0==oo`003goo00<007ooOol017oo00D007ooOomoo`00009oo`05001oogooOol00003
Ool01000Oomoo`000Woo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oo`00Ool00004Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`08Ool2000=Ool01@00Oomoogoo00000Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00003Ool01000Oomo
o`0017oo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`3POol000moo`03001o
ogoo00Aoo`05001oogooOol00002Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol0
0goo00D007ooOomoo`0000=oo`05001oo`00Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Ool0000;Ool2000;Ool01@00Oomoogoo00000Woo00<007ooOol01Woo00<007ooOol00goo00<0
07oo00000goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00D0
07ooOomoo`000>9oo`003goo00<007oo000017oo00D007ooOomoo`00009oo`05001oogooOol00003
Ool00`00Oomoo`03Ool00`00Ool00004Ool40003Ool01@00Ool007oo000017oo00<007ooOol017oo
00<007ooOol00goo00<007oo00000goo1@001Goo0P002Goo00D007ooOomoo`00009oo`D000Aoo`03
001oogoo00=oo`03001oo`0000=oo`D000=oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00Aoo`@00>9oo`003goo0`0017oo00D007ooOomoo`00009oo`80009oo`05001oogooOol00005Ool3
0003Ool01@00Oomoogoo00000goo00D007oo001oo`0000Aoo`03001oogoo00Aoo`03001oogoo009o
o`05001oogooOol0000:Ool2000;Ool50002Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D0
07ooOomoo`00009oo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01`00Oomo
ogoo001oo`0000=oo`03001oogoo0>1oo`003goo00<007oo00001Goo0`000Woo0P0000=oo`000000
0goo10000goo00<007oo000017oo0`000goo0`0000=oo`00Ool00Woo0`001Woo00@007ooOomoo`<0
0004Ool000000007Ool20007Ool00`00Ool00003Ool01@00Oomoogoo00000goo0`001Goo00@007oo
Oomoo`<00004Ool000000002Ool30003Ool40003Ool30005Ool30003Ool30005Ool00`00Ool0003K
Ool000moo`05001oogooOol0000AOol00`00Oomoo`03Ool01@00Oomoogoo00006Goo00<007ooOol0
67oo00<007oo00000goo00D007ooOomoo`0000]oo`03001oogoo015oo`03001oogoo01Uoo`03001o
o`000=]oo`003Woo1P004Goo00<007ooOol00Woo1P004Woo00<007ooOol00Woo0`006Woo00<007oo
00000Woo0`0000Aoo`00000000Qoo`<001=oo`03001oogoo00Eoo`03001oogoo015oo`03001oo`00
0=]oo`00ogooRGoo003oOon9Ool00?moohUoo`00ogooRGoo000POol00`00Oomoo`0FOol3000fOol0
0`00Oomoo`0DOol00`00Oomoo`1MOol00`00Oomoo`0DOol00`00Oomoo`1bOol00`00Oomoo`04Ool0
0`00Oomoo`09Ool001moo`03001oogoo01Yoo`03001oogoo01ioo`03001oogoo01=oo`03001oogoo
00=oo`03001oogoo00aoo`03001oogoo04Uoo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo05ioo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
009oo`007goo00<007ooOol027oo100017oo1@000Woo100017oo0P0000Aoo`00001oo`@000Aoo`<0
00aoo`03001oogoo00Yoo`<000Eoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Uoo`@0
00Aoo`800003Ool0000000D000Eoo`8000=oo`D000Aoo`8000=oo`D000=oo`<000aoo`03001oogoo
00Yoo`<000Eoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Uoo`@000Aoo`800003Ool0
000000D000=oo`@000Aoo`800003Ool0000000D000Eoo`8000=oo`D000Aoo`8000=oo`D000=oo`<0
00aoo`03001oogoo00Yoo`<000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo005oo`00
7goo00<007ooOol02Goo00<007ooOol01Woo00D007ooOomoo`0000=oo`05001oogooOol00002Ool2
0003Ool00`00Oomoo`03Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Aoo`03001oogoo019o
o`03001oogoo00Uoo`05001oogooOol00002Ool00`00Oomoo`020002Ool01@00Oomoogoo00000goo
00@007ooOol000Aoo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool01@00Oomoogoo
00005goo00D007ooOomoo`0000Aoo`03001oogoo019oo`03001oogoo00Uoo`05001oogooOol00002
Ool00`00Oomoo`020002Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`03001oogoo0080
009oo`05001oogooOol00003Ool01000Oomoo`0017oo00<007ooOol00goo00@007ooOol000Aoo`03
001oogoo009oo`05001oogooOol0000GOol01@00Oomoogoo000017oo00<007ooOol017oo00<007oo
Ool027oo000OOol00`00Oomoo`09Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00005Ool00`00Oomoo`0IOol01@00Oomoogoo000017oo00<007ooOol0
4Woo00<007ooOol03Goo00@007ooOol000=oo`04001oogoo0003Ool01@00Oomoogoo00001goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000Ao
o`03001oogoo019oo`03001oogoo00eoo`04001oogoo0003Ool01000Oomoo`000goo00<007ooOol0
17oo00@007ooOol000=oo`04001oogoo0003Ool01@00Oomoogoo00001goo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol06Goo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`03001oogoo00Qoo`007Woo00<007ooOol02Woo00<007oo00001Woo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00001Goo1@005goo00D007ooOomoo`0000Eoo`03001oogoo
011oo`03001oogoo00ioo`04001oogoo0003Ool01000Oomoo`000goo00D007ooOomoo`0000Moo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`D001Moo`05001oogooOol00005Ool00`00
Oomoo`0@Ool00`00Oomoo`0>Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogooOol30003
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo00=oo`03
001oogoo00Eoo`03001oogoo009oo`D001Moo`05001oogooOol00005Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool001moo`03001oogoo00Uoo`<000Ioo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00@007ooOomoo`8000Aoo`05001oogooOol0000GOol01@00Oomoogoo000017oo00<007ooOol0
4Woo00<007ooOol02Woo0`000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00005goo00D0
07ooOomoo`0000Aoo`03001oogoo019oo`03001oogoo00Yoo`<000=oo`05001oogooOol00002Ool0
1@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol00002Ool01@00Oomoogoo0000
0goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomo
o`0001Moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`08Ool001moo`03001oogoo
00=oo`03001oo`0000=oo`03001oo`0000Aoo`<000Aoo`D00003Ool00000009oo`80009oo`800003
Ool0000000=oo`<000Aoo`03001oo`00015oo`05001oogooOol00004Ool00`00Oomoo`0BOol00`00
Oomoo`03Ool00`00Ool00003Ool00`00Oomoo`03Ool20002Ool20002Ool40003Ool40003Ool30004
Ool40005Ool00`00Oomoo`03Ool30004Ool00`00Ool0000AOol01@00Oomoogoo000017oo00<007oo
Ool04Woo00<007ooOol00goo00<007oo00000goo00<007ooOol00goo0P000Woo0P000Woo100017oo
0`000Woo0P000Woo0P000Woo10000goo10000goo0`0017oo10001Goo00<007ooOol00goo0`0017oo
00<007oo00004Goo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Qoo`007goo00<0
07ooOol00goo00<007oo00000goo00D007ooOomoo`0002Ioo`03001oo`00015oo`05001oogooOol0
0004Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Ool00003Ool01@00Oomoogoo00002Goo00<0
07ooOol01Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02Woo00<007oo00004Goo00D0
07ooOomoo`0000Aoo`03001oogoo019oo`03001oogoo00=oo`03001oo`0000=oo`05001oogooOol0
0009Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Ool0000AOol01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol027oo000P
Ool00`00Oomoo`02Ool00`00Ool00002Ool60004Ool00`00Oomoo`0OOol00`00Ool0000BOol30004
Ool00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Ool00004Ool40008Ool20007Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool3000<Ool00`00Ool0000BOol30004Ool00`00Oomoo`0D
Ool00`00Oomoo`02Ool00`00Ool00004Ool40008Ool2000COol20007Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool3000<Ool00`00Ool0000BOol30004Ool00`00Oomoo`04Ool00`00
Oomoo`09Ool00?moohUoo`00ogooRGoo003oOon9Ool00?moohUoo`00G7oo0`00?goo00<007ooOol0
17oo00<007ooOol0EWoo00<007ooOol057oo00<007ooOol04Woo0`00B7oo00<007ooOol047oo001O
Ool00`00Oomoo`0kOol00`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomoo`0COol00`00Oomoo`03
Ool00`00Oomoo`0<Ool00`00Oomoo`0DOol00`00Oomoo`0bOol00`00Oomoo`0COol00`00Oomoo`03
Ool00`00Oomoo`09Ool0011oo`<000Aoo`<000Aoo`800003Ool0000000<00004Ool000000003Ool2
0004Ool30003Ool40002Ool300001Goo00000000Ool010000goo10000goo1@000Woo10000Woo0`00
00=oo`00000020000Woo0`000Woo0`0000Aoo`00000000=oo`8000=oo`@001=oo`03001oogoo00Ao
o`03001oogoo00Uoo`@000Aoo`<000Aoo`<000Eoo`8000=oo`D000=oo`<0009oo`<00004Ool00000
000:Ool00`00Oomoo`0:Ool30005Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool6
0003Ool40003Ool2000017oo000007oo0`0000=oo`00Ool00goo0P000goo1@000goo0`000Woo0`00
00Aoo`00000000Yoo`03001oogoo00Yoo`<000Eoo`03001oogoo00Aoo`03001oogoo00Qoo`003goo
00D007ooOomoo`00009oo`05001oogooOol00002Ool00`00Oomoo`020002Ool01@00Oomoogoo0000
0goo00@007ooOol0009oo`05001oogooOol00003Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo
00D007ooOomoo`00009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`08001oogoo001oo`00Ool0009oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`05001oogooOol00008Ool20008Ool00`00Oomoo`04Ool00`00Oomoo`09Ool01@00
Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol00003Ool01000Oomoo`0017oo00<0
07ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol0000GOol01@00Oomoogoo000017oo00<0
07ooOol04Woo00<007ooOol02Goo00D007ooOomoo`00009oo`05001oogooOol00002Ool00`00Oomo
o`0200000goo001oo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00D007oo
Oomoo`00009oo`05001oogooOol0000GOol01@00Oomoogoo000017oo00<007ooOol03goo000>Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol00003Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`03Ool50006Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`08001oogoo001oo`00Ool0009oo`03
001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`08Ool20006Ool00`00
Oomoo`04Ool00`00Oomoo`0=Ool01000Oomoo`001Woo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol0000GOol01@00Oomoogoo000017oo00<0
07ooOol04Woo00<007ooOol02Goo00<007ooOol017oo00D007ooOomoo`00009oo`07001oogooOol0
07oo00000goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00009o
o`05001oogooOol0000GOol01@00Oomoogoo000017oo00<007ooOol03goo000>Ool00`00Oomoo`05
Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol00003Ool00`00Oomoo`03
Ool50003Ool00`00Oomoo`04Ool00`00Ool00004Ool30004Ool30005Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`08001oogoo001oo`00Ool0009oo`D0009oo`05001oogooOol00003Ool0
0`00Oomoo`04Ool30003Ool50005Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomo
o`050002Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00D007ooOomoo`0001Moo`05001oogooOol00005Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool00`00
Ool00004Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`@000Aoo`03001oogoo00Eoo`03
001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo00005goo00D007ooOomoo`0000Eoo`03
001oogoo00ioo`003Woo00<007ooOol01Goo00D007ooOomoo`00009oo`05001oogooOol00002Ool2
0002Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`8000Eoo`03001oo`0000=oo`05001o
ogooOol00002Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`04001oogooOol20002Ool0
2000Oomoo`00Ool007oo0002Ool01@00Oomoogoo00000Woo0P000Woo00D007ooOomoo`0000Eoo`05
001oogooOol0000:Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool30003Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol00002
Ool20002Ool00`00Oomoo`0EOol01@00Oomoogoo000017oo00<007ooOol04Woo00<007ooOol02Goo
0`0017oo00D007ooOomoo`00009oo`07001oogooOol007oo00000goo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol00Woo00D007ooOomoo`00009oo`80009oo`03001oogoo01Eoo`05001oogoo
Ool00004Ool00`00Oomoo`0?Ool000ioo`03001oogoo00Ioo`<0009oo`80009oo`800004Ool00000
Ool20003Ool40004Ool30003Ool200000goo00000004Ool00`00Oomoo`03Ool30004Ool30003Ool3
0004Ool5000017oo000007oo0P000Woo0`0000=oo`00Ool00goo0`000Woo0P0000=oo`0000000goo
100017oo0`002Goo0P0027oo00<007ooOol017oo00<007ooOol00goo00<007oo00000goo00<007oo
Ool01Goo0`0017oo0`000goo10000goo0`001Goo0`000Woo0P0000=oo`00000017oo00<007oo0000
4Goo00D007ooOomoo`0000Aoo`03001oogoo019oo`03001oogoo00=oo`03001oo`0000=oo`03001o
o`0000Eoo`L0009oo`80009oo`<000Aoo`@000=oo`<000Eoo`<0009oo`800003Ool0000000Aoo`03
001oo`00015oo`05001oogooOol00004Ool00`00Oomoo`0?Ool000moo`05001oogooOol0000HOol0
0`00Oomoo`0COol00`00Oomoo`0kOol00`00Oomoo`0JOol00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Ool00003Ool01@00Oomoogoo00004Goo00<007ooOol06Goo00<007oo00004Goo00D007ooOomo
o`0000Aoo`03001oogoo019oo`03001oogoo00=oo`03001oo`0000=oo`05001oogooOol0000HOol0
0`00Oomoo`0IOol00`00Ool0000AOol01@00Oomoogoo000017oo00<007ooOol03goo000@Ool4000H
Ool00`00Oomoo`0BOol2000DOol00`00Oomoo`0VOol00`00Oomoo`0KOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Ool00004Ool4000AOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Ool0000B
Ool30004Ool00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Ool00002Ool6000HOol00`00Oomoo`05
Ool00`00Oomoo`0AOol00`00Ool0000BOol30004Ool00`00Oomoo`0@Ool00?moohUoo`00ogooRGoo
003oOon9Ool00?moohUoo`00ogooRGoo0036Ool00`00Oomoo`2oOol0011oo`<000Aoo`<000Aoo`80
0003Ool0000000<00004Ool000000003Ool20004Ool30003Ool40003Ool500001Goo00000000Ool0
0`000Woo0`000goo100017oo0`000Woo1`000Woo0`000Woo0`0000Aoo`00000000=oo`8000=oo`@0
01Uoo`<000=oo`D000Aoo`8000=oo`D000=oo`<000aoo`03001oogoo0;ioo`003goo00D007ooOomo
o`00009oo`05001oogooOol00002Ool00`00Oomoo`020002Ool01@00Oomoogoo00000goo00@007oo
Ool0009oo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`05001oogooOol00002Ool01@00Ool007oo0000
0Woo00D007ooOomoo`00009oo`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00
00Qoo`8000moo`03001oogoo00Aoo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool0
1@00Oomoogoo0000c7oo000>Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
009oo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo
00D007oo001oo`00009oo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool2000=Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`3>Ool000ioo`03001oogoo00Eoo`05001oogooOol00002Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`D000=oo`03001oogoo00Eoo`03001oogoo009o
o`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`03Ool50002Ool01@00Ool007oo0000
0Woo1@000Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`<000=oo`D000Eoo`8000]oo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`D00<aoo`003Woo00<007oo
Ool01Goo00D007ooOomoo`00009oo`05001oogooOol00002Ool20002Ool01@00Oomoogoo00001Goo
00D007ooOomoo`0000=oo`8000Ioo`03001oogoo009oo`80009oo`04001oogoo0003Ool01000Oomo
ogoo0P0017oo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool01@00Oomoogoo00000Woo0P00
0Woo00D007ooOomoo`0000Eoo`05001oogooOol0000:Ool2000=Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo0000c7oo000>Ool00`00Oomoo`06
Ool30002Ool20002Ool2000017oo000007oo0P000goo100017oo0`000goo0P0000=oo`00000017oo
00@007ooOomoo`800003Ool0000000Aoo`<000=oo`800003Ool0000000=oo`<0009oo`<00003Ool0
07oo00=oo`<0009oo`800003Ool0000000=oo`@000Aoo`<000Uoo`8000Moo`03001oo`00009oo`04
001oogoo0002Ool00`00Ool000020004Ool40005Ool00`00Oomoo`03Ool30004Ool00`00Ool00036
Ool000moo`05001oogooOol0000HOol00`00Oomoo`0COol00`00Oomoo`0dOol00`00Oomoo`0IOol0
0`00Ool00002Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol02Woo
00<007oo0000aWoo000@Ool4000HOol00`00Oomoo`0AOol5000dOol00`00Oomoo`0IOol00`00Ool0
0002Ool70003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool3000<Ool00`00Ool00036Ool00?moohUo
o`00ogooRGoo003oOon9Ool00?moohUoo`007Goo0`00ogooJGoo000POol00`00Oomoo`20Ool00`00
Oomoo`3ROol000ioo`@000Aoo`<00004Ool007ooOol40004Ool30002Ool50003Ool40004Ool30003
Ool300000goo001oo`020002Ool200000goo000000030004Ool30003Ool50003Ool30004Ool00`00
Ool0000@Ool40004Ool3000017oo001oogoo1@000Woo100017oo0`001Goo00<007ooOol0hGoo000?
Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001oogooOol00002
Ool01@00Oomoogoo00000goo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007oo00002Goo0P001Woo00<007ooOol00goo00D007ooOomoo`0000Eo
o`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo0000j7oo000?Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`05001oogooOol00003
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007oo000017oo00D007oo
Oomoo`00009oo`03001oogoo00Ioo`03001oogoo009oo`05001oogooOol00002Ool01@00Ool007oo
00002Woo0P0017oo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo00Ioo`04001oogoo
003/Ool000moo`@000=oo`@0009oo`05001oogooOol00003Ool50002Ool01@00Oomoogoo00000goo
00<007ooOol00goo1@000Woo10000goo0P001Goo00D007ooOomoo`00009oo`D000Aoo`03001oogoo
009oo`05001oogooOol00002Ool01@00Ool007oo00000Woo1@001Goo0P000Woo00<007oo000017oo
10001Goo00<007ooOol00goo0`000goo1@00j7oo000?Ool01`00Oomoogoo001oo`0000=oo`04001o
ogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0100017oo0P0017oo00L007ooOomoo`00Ool0
0003Ool01`00Oomoogoo001oo`0000Aoo`@000=oo`05001oogooOol00004Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00D007ooOomoo`0000Yoo`8000Aoo`<000=oo`05001oogooOol00005Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007ooOomoo`000>Qoo`003goo00D007ooOomoo`00
009oo`<000Aoo`D000=oo`<000=oo`05001oogooOol00002Ool200000goo00000003Ool30003Ool3
0004Ool00`00Oomoo`020002Ool01@00Oomoogoo00000goo0`001Goo00<007ooOol00goo0`000Woo
0`0000Aoo`00000000Moo`8000Ioo`03001oo`0000Aoo`<000Ioo`03001oogoo00=oo`<000Aoo`<0
0>Uoo`003goo00D007ooOomoo`0001Moo`05001oogooOol0000GOol00`00Oomoo`04Ool01@00Oomo
ogoo00002goo00<007ooOol07Woo00D007ooOomoo`0000]oo`03001oogoo0?Ioo`003Woo1@005goo
1@005goo0P001Goo1@002Woo0`007goo1P002Goo0`00n7oo003oOon9Ool00?moohUoo`00ogooRGoo
003oOon9Ool004Ioo`<001=oo`<003Qoo`03001oogoo04Ioo`<001=oo`<0025oo`03001oogoo06]o
o`00Agoo00<007ooOol05Goo00<007ooOol0=7oo00<007ooOol0B7oo00<007ooOol05Goo00<007oo
Ool02Goo00<007ooOol04goo00<007ooOol00goo00<007ooOol0I7oo000@Ool30004Ool30003Ool5
0002Ool50003Ool30003Ool40004Ool30004Ool2000017oo000007oo10000goo1@0000Eoo`000000
07oo00<00003Ool000000080009oo`<0009oo`04001oogooOol2000017oo000007oo1@000goo0`00
0goo10004goo00<007ooOol02Woo0`000goo1@0017oo0P000goo1@000goo0`0017oo0`000goo1000
17oo0`0017oo0P0000Aoo`00001oo`@000=oo`D00005Ool00000001oo`0300000goo00000002000<
Ool00`00Oomoo`0:Ool30005Ool00`00Oomoo`04Ool00`00Oomoo`1SOol000moo`05001oogooOol0
0002Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000=o
o`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`020002Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
009oo`8000Aoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo000027oo0P0027oo
00<007ooOol02goo00<007ooOol017oo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009o
o`05001oogooOol00002Ool01@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`00009o
o`03001oogoo0080009oo`05001oogooOol00004Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo01Ioo`05001oogooOol00004Ool00`00Oomoo`1ZOol000ioo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Aoo`05001oogooOol00004Ool01@00Oomoogoo00001Goo00D0
07ooOomoo`00009oo`05001oogooOol00002Ool01@00Oomoogoo000017oo00<007ooOol00Woo00L0
07ooOomoo`00Ool00003Ool01`00Oomoogoo001oo`0000Aoo`05001oogooOol00004Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool00`00Oomoo`08Ool20006Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo00001Goo00D007ooOomoo`00009oo`05001oogooOol00002Ool01@00Oomoogoo0000
17oo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0FOol01@00Oomoogoo0000
17oo00<007ooOol0JWoo000>Ool00`00Oomoo`05Ool50004Ool00`00Oomoo`04Ool01@00Oomoogoo
00000goo0`000Woo00<007ooOol00goo00D007ooOomoo`00009oo`05001oogooOol00002Ool01@00
Oomoogoo000017oo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool01000Oomoogoo10000goo
00D007ooOomoo`0000Aoo`03001oogoo009oo`D000=oo`<000=oo`D000Eoo`8000=oo`03001oogoo
00aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`D00003Ool0
07oo009oo`<0009oo`03001oogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00D0
07ooOomoo`0000Aoo`03001oogoo009oo`07001oogooOol007oo00000goo00<007ooOol05Woo00D0
07ooOomoo`0000Eoo`03001oogoo06Uoo`003Woo00<007ooOol01Goo00D007ooOomoo`0000Aoo`03
001oogoo00Aoo`05001oogooOol00008Ool20004Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
009oo`05001oogooOol00004Ool00`00Oomoo`02Ool20002Ool00`00Ool00003Ool01@00Oomoogoo
00000goo00@007ooOol000=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool0
1@00Oomoogoo00002Woo0P001Woo00<007ooOol02goo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol00Woo00L007ooOomoo`00Ool00008Ool20004Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`02Ool20002Ool00`00Ool0
0003Ool00`00Oomoo`0FOol01@00Oomoogoo000017oo00<007ooOol0JWoo000>Ool00`00Oomoo`06
Ool30005Ool00`00Oomoo`04Ool01@00Oomoogoo00001goo0P0000=oo`0000000goo0`000Woo0P00
0Woo0P0000=oo`0000000`000goo0`000goo0P0000=oo`0000000goo1@000Woo00H007ooOomoo`00
Ool20002Ool20004Ool00`00Oomoo`03Ool30004Ool30009Ool20008Ool00`00Oomoo`03Ool00`00
Ool00002Ool01000Oomoo`000Woo00<007oo00000P0017oo10001Goo00<007ooOol00goo0`000Woo
00<007ooOol01Goo0P0000=oo`0000000goo0`000Woo0P000Woo0P0000=oo`0000000`000goo0`00
0goo0P0000=oo`0000000goo1@000goo00<007oo00004Goo00D007ooOomoo`0000Aoo`03001oogoo
06Yoo`003goo00D007ooOomoo`0000]oo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0
000cOol01@00Oomoogoo00002goo00<007ooOol087oo00<007ooOol00goo00<007oo00000Woo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Uoo`05001oogooOol0000d
Ool00`00Ool0000AOol01@00Oomoogoo000017oo00<007ooOol0JWoo000@Ool40009Ool30004Ool3
0005Ool4000POol00`00Oomoo`0?Ool5000:Ool3000SOol00`00Oomoo`02Ool00`00Ool00002Ool7
0003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool3000<Ool4000POol00`00Oomoo`0AOol00`00Ool0
000BOol30004Ool00`00Oomoo`1[Ool00?moohUoo`00ogooRGoo003oOon9Ool00?moohUoo`00Hgoo
0`00:Woo00<007ooOol017oo00<007ooOol0<goo00<007ooOol057oo00<007ooOol0;7oo00<007oo
Ool017oo00<007ooOol0Jgoo001VOol00`00Oomoo`0VOol00`00Oomoo`04Ool00`00Oomoo`0AOol0
0`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0JOol0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`1TOol0011oo`<000Aoo`<000=oo`D0009oo`D0
0003Ool00000008000Aoo`@000=oo`<00003Ool007oo00L0009oo`<0009oo`<00005Ool00000001o
o`03000017oo001oogoo10000goo10000goo1@0000Eoo`00000007oo00<00003Ool00000008001=o
o`03001oogoo00Aoo`03001oogoo00=oo`<000Aoo`<000Eoo`03001oogoo00Uoo`D000=oo`<000Ao
o`<000Eoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo009oo`D000=oo`<000Eoo`03001o
ogoo00Uoo`D000=oo`<000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo06=oo`003goo
00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007oo001oo`00009oo`05001oogoo
Ool00002Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00005Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Qoo`8000Qoo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo00004Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`0BOol00`00Oomoo`04
Ool00`00Oomoo`02Ool01@00Oomoogoo000047oo00D007ooOomoo`00009oo`05001oogooOol00004
Ool00`00Oomoo`04Ool00`00Oomoo`1ZOol000ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Ool007oo00000Woo00<007ooOol017oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001o
ogoo00Qoo`8000Ioo`03001oogoo00Aoo`03001oogoo00Ioo`04001oogoo0003Ool00`00Oomoo`0@
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Aoo`03001oogoo019oo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000AOol00`00Oomoo`03Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007ooOol0JWoo000>Ool00`00Oomoo`05Ool50004Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`03Ool40003Ool01@00Ool007oo0000
0Woo1@000Woo00D007ooOomoo`00009oo`@000Aoo`03001oogoo009oo`05001oogooOol00005Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo0`000goo1@001Goo0P000goo00<007ooOol017oo00<0
07ooOol01goo00@007ooOol000=oo`03001oogoo011oo`03001oogoo009oo`05001oogooOol00002
Ool01@00Oomoogoo00001Goo00<007ooOol047oo00<007ooOol01Goo00<007ooOol00Woo00D007oo
Oomoo`00019oo`03001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`04Ool00`00Oomoo`1Y
Ool000ioo`03001oogoo00Eoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool3
0005Ool20003Ool01@00Oomoogoo00000goo00D007oo001oo`00009oo`05001oogooOol00002Ool0
1`00Oomoogoo001oo`0000=oo`03001oogoo009oo`8000=oo`05001oogooOol00005Ool00`00Oomo
o`02Ool20002Ool01000Oomoo`000goo00<007ooOol027oo0P001Woo00<007ooOol017oo00<007oo
Ool017oo0P000goo00D007ooOomoo`00019oo`03001oogoo009oo`05001oogooOol00002Ool01@00
Oomoogoo000017oo00<007ooOol04Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00
01=oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1ZOol000io
o`03001oogoo00Ioo`<000Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oo`0000Aoo`800003
Ool00000009oo`<000=oo`<00003Ool007oo00=oo`<000=oo`05001oo`00Ool00002Ool30004Ool2
00000goo00000002Ool50002Ool30003Ool200000goo00000004Ool30009Ool20008Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool01000Oomoo`000goo00<007ooOol03Woo00<007oo000017oo00D007oo
Oomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Ool00004
Ool01@00Oomoogoo000057oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo06Yoo`003goo00D007ooOomoo`0000]oo`03001oogoo00Aoo`03001oogoo009oo`05001oogoo
Ool0000NOol200000goo0000000lOol00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`00015oo`8000Aoo`05001oogooOol00002Ool01@00Oomoogoo000017oo00<0
07ooOol04Woo00<007ooOol00goo0P0017oo00D007ooOomoo`00011oo`05001oogooOol00002Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0JWoo000@Ool40009Ool30004Ool30003
Ool6000MOol20003Ool2000HOol00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Oomoo`02Ool30004
Ool3000COol00`00Oomoo`03Ool30004Ool30004Ool00`00Oomoo`0DOol00`00Oomoo`03Ool00`00
Oomoo`03Ool3000BOol30004Ool30004Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool00?moohUoo`00
ogooRGoo003oOon9Ool00?moohUoo`00@7oo0`00:Woo00<007ooOol017oo00<007ooOol0;7oo00<0
07ooOol057oo00<007ooOol07Woo00<007ooOol017oo00<007ooOol0Xgoo0013Ool00`00Oomoo`0V
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`0:Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`2L
Ool0011oo`<000Aoo`<000=oo`D0009oo`D00005Ool00000001oo`0300001Woo00000000Ool0009o
o`@000=oo`@000=oo`D00005Ool00000001oo`0300000goo00000002000COol00`00Oomoo`04Ool0
0`00Oomoo`03Ool30005Ool00`00Oomoo`09Ool50003Ool30004Ool30005Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`0:Ool30005Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`2KOol000moo`05001oogooOol00002Ool01@00Oomoogoo000017oo
00<007ooOol017oo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogoo
Ool00008Ool20008Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00004Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`0BOol00`00Oomoo`02
Ool01@00Oomoogoo000047oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo0:9oo`00
3Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00L007ooOomo
o`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol0
0Woo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`8000Ioo`03001oogoo00Aoo`03001oogoo009o
o`05001oogooOol0000BOol00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Ao
o`03001oogoo019oo`03001oogoo009oo`05001oogooOol0000@Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol0XWoo000>Ool00`00Oomoo`05Ool50004Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo100017oo00<007ooOol00Woo00D007ooOomoo`0000Eoo`03
001oogoo009oo`05001oogooOol00003Ool30003Ool50005Ool20003Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool01@00Oomoogoo00004Woo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogoo
Ool00005Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool01@00Oomoogoo000047oo00D007ooOomoo`00
00Eoo`03001oogoo00Aoo`03001oogoo0:5oo`003Woo00<007ooOol01Goo00D007ooOomoo`0000Ao
o`03001oogoo00Aoo`03001oogoo009oo`07001oogooOol007oo00000goo00<007ooOol00Woo0P00
0goo00D007ooOomoo`0000Eoo`03001oogoo009oo`80009oo`04001oogoo0003Ool00`00Oomoo`08
Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00004Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`0BOol00`00Oomoo`02Ool01@00
Oomoogoo000047oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo0:9oo`003Woo00<0
07ooOol01Woo0`001Goo00<007ooOol017oo00<007ooOol00Woo00D007oo001oo`00009oo`<000Ao
o`800003Ool00000009oo`D0009oo`<000=oo`800003Ool0000000Aoo`<000Uoo`8000Qoo`03001o
ogoo00Aoo`03001oogoo009oo`05001oogooOol0000@Ool00`00Ool00004Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000Aoo`03001oogoo019oo`03001oogoo009oo`05001oogooOol0000@Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0XWoo000?Ool01@00Oomoogoo00002goo
00<007ooOol017oo00<007ooOol00Woo0P0000=oo`000000?7oo00<007ooOol017oo00<007ooOol0
0Woo00D007ooOomoo`00015oo`8000Aoo`05001oogooOol00002Ool01@00Oomoogoo000017oo00<0
07ooOol04Woo00<007ooOol00Woo00D007ooOomoo`00011oo`05001oogooOol00004Ool00`00Oomo
o`04Ool00`00Oomoo`2ROol0011oo`@000Uoo`<000Aoo`<000=oo`8000=oo`8001Qoo`03001oogoo
025oo`03001oogoo00Aoo`03001oogoo009oo`<001=oo`03001oogoo00=oo`<000Aoo`<000Aoo`03
001oogoo01Aoo`03001oogoo009oo`<0019oo`<000Aoo`03001oogoo00Aoo`03001oogoo0:=oo`00
ogooRGoo003oOon9Ool00?moohUoo`00ogooRGoo000MOol30029Ool3000eOol3002TOol001eoo`03
001oogoo08aoo`03001oogoo03Eoo`03001oogoo01ioo`03001oogoo081oo`000Woo0`0017oo0`00
0goo1@000Woo1@000Woo00<007ooOol02Woo10001Goo0`0017oo0`0017oo0P0000=oo`0000001`00
0Woo0`000Woo0`0000Aoo`00000000=oo`8000Uoo`@000Eoo`<000=oo`@0009oo`L00006Ool00000
001oo`0017oo0P001Goo0P000goo1@0000Eoo`00000007oo00<00003Ool00000008000Yoo`@000Eo
o`8000=oo`@000=oo`<00003Ool007oo00=oo`8000Aoo`<000=oo`@000=oo`D000=oo`<000=oo`@0
00aoo`03001oogoo07moo`0000=oo`00Ool00Woo00@007ooOol000=oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00]oo`04001oogoo0003Ool01@00Oomoogoo00000Woo
00D007ooOomoo`00009oo`03001oogoo0080009oo`05001oo`00Ool00002Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`0000=oo`04001oogoo0009Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo
00<007ooOol00goo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool01000Oomoo`000goo00@0
07ooOol000Aoo`03001oogoo009oo`07001oogooOol007oo00000goo00<007ooOol027oo00D007oo
Oomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`07001oogooOol007oo00000goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00
009oo`05001oogooOol0002=Ool00003001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00<007oo
Ool017oo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool00`00Oomoo`04Ool01@00Oomoogoo
00000goo00<007ooOol02Woo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo00=oo`07
001oo`00Ool007oo00000goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool00Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0<Ool01@00Oomoogoo00001Woo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`2;Ool00003001oogoo00Eoo`D000Aoo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol00002Ool01@00Oomoogoo
00000Woo00<007ooOol017oo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool50002Ool01@00
Oomoogoo00000goo00<007ooOol02Woo00<007oo000017oo00D007ooOomoo`0000=oo`03001oogoo
00=oo`05001oo`00Ool00002Ool40004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00aoo`05001oogooOol00006Ool00`00Oomoo`03
Ool40004Ool00`00Oomoo`03Ool500000goo001oo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool5
0003Ool3002>Ool00003001oogoo00Eoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol0
0002Ool01@00Oomoogoo00000Woo00D007oo001oo`00009oo`05001oogooOol00002Ool20002Ool0
1@00Oomoogoo000037oo0`0017oo00D007ooOomoo`0000=oo`8000Aoo`07001oo`00Ool007oo0000
0goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00Woo0P000Woo00<0
07oo00000goo00<007ooOol02Goo0`0017oo00<007ooOol017oo0P000goo00D007ooOomoo`0000Ao
o`03001oogoo00=oo`07001oogooOol007oo00000goo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`00009oo`05001oogooOol0002=Ool00003001oogoo00Ioo`<000Eoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo00Eoo`03001oo`0000=oo`05001oogooOol00003Ool30004Ool3
0002Ool20002Ool200001Woo00000000Ool000Aoo`<0009oo`800003Ool0000000=oo`@000Yoo`03
001oo`0000Eoo`<000=oo`800004Ool00000Ool300000goo001oo`02Ool30004Ool40003Ool40003
Ool30003Ool200000goo00000003Ool50009Ool00`00Oomoo`04Ool40003Ool200000goo00000002
Ool30004Ool40004Ool30003Ool50002Ool30005Ool30004Ool30004Ool00`00Ool00027Ool00003
Ool007oo009oo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03
001oo`0000=oo`04001oogoo000^Ool00`00Oomoo`0:Ool01@00Oomoogoo00007goo00<007ooOol0
17oo00<007ooOol07goo00D007ooOomoo`0000=oo`03001oogoo019oo`03001oogoo02Moo`03001o
o`0008Moo`000Woo10002Goo0`0017oo0`0017oo0`001Goo00<007oo00000Woo1000;goo00<007oo
Ool02Goo1P007goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol067oo10000goo00<007oo
Ool04Woo00<007ooOol04goo00<007ooOol04Goo00<007oo0000Qgoo003oOon9Ool00?moohUoo`00
ogooRGoo0000\
\>"], "Graphics",
  ImageSize->{392, 224},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Best way to edit style sheets", "Subsection"],

Cell["\<\
Start a new notebook or open an existing notebook as a \
template\
\>", "Item",
  CellMargins->{{Inherited, Inherited}, {Inherited, 10}},
  CounterAssignments->{{"ItemizedText", 0}}],

Cell[TextData[{
  "Select a style from the ",
  StyleBox["Format:Style Sheet", "SR"]
}], "Item"],

Cell[TextData[{
  "Select the ",
  StyleBox["Import Private Copy", "SR"],
  " option in the ",
  StyleBox["Format:Edit Style Sheet", "SR"],
  " dialog box"
}], "Item"],

Cell["\<\
The style sheet opens, and you make your changes by selecting \
options from the formatting menus or the option inspector. You can also \
unformat the cells and apply options by editing the cell expressions.  \
\>", 
  "Text"],

Cell["\<\
Importing the style sheet allows you to see your changes to cells \
that use the styles being edited. If you do not import the style sheet, you \
have to reapply the shared style sheet to see style edits on actual cells in \
your template or test document. \
\>", "Text"],

Cell[TextData[{
  "Once you\[CloseCurlyQuote]re happy with the edited styles, do ",
  StyleBox["Save As", "SR"],
  " to save the styles out as a new, unique style sheet, or select all the \
cells, copy, and paste into a new notebook, which can be saved as the new \
stylesheet."
}], "Text"],

Cell[TextData[{
  "Style sheets are notebooks, like any other notebooks, except that all the \
active styles are cells with the ",
  StyleBox["StyleData", "MR"],
  " option, with the style name and environment names as arguments."
}], "Text"],

Cell[TextData[{
  "StyleMenuListing is the option that determines whether or not a style will \
appear in the the style menu. All styles listed in the menu are listed in the \
order they appear in the style sheet. Unlisted styles can be selected with ",
  StyleBox["Other...", "SR"],
  " in the Style menu: \[AltKey]\[KeyBar]\[LeftModified]0\[RightModified]. \
You must know the name in order to enter it."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inheritance", "Subsection"],

Cell["\<\
Be aware of the concept of inheritance, where styles applied at \
different levels within a document defer to the other levels. This accounts \
for a lot of inscrutable behavior. Please refer to the online docs for a \
discussion of this concept. Note that:\
\>", "Text"],

Cell["\<\
Styles defer to the Default style sheet when not defined in the \
selected stylesheet, if they use the same names as those in Default.nb. If \
they use other names that aren\[CloseCurlyQuote]t defined anywhere, they \
result in the absolute default, which is 12 pt Times.\
\>", "Item"],

Cell["\<\
There are some inheritance issues within the style sheet worth \
noting:\
\>", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, 14}}],

Cell[TextData[{
  StyleBox["Environment styles", "BF"],
  " set font sizes and a few other options that will apply throughout, so \
there is no need to set these particular options again for the ",
  StyleBox["Working", "BF"],
  " cell styles if they remain the same. Environments besides ",
  StyleBox["Working", "BF"],
  " (default on-screen mode) include ",
  StyleBox["Printout", "BF"],
  " (the mode usually used for printing, but also to preview the look of \
print on screen) and any number of others. The ",
  StyleBox["AllBrackets", "BF"],
  " environment in some style sheets (such as the latest version of \
HelpBorwser.nb) lets you see the cell brackets in order to simplify the \
editing of your document. The brackets are turned off in Working so as not to \
clutter the appearances of a document in the help browser. ",
  ButtonBox["Environment sample",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "EnvironmentSample.nb"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Item"],

Cell[TextData[{
  StyleBox["Printout", "BF"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is the environment used for any conversion to EPS in the front end, since \
EPS files are intended for printing. This means the font sizes in an exported \
cell will reflect the settings for the Printout Environment."
}], "Text"],

Cell[TextData[{
  StyleBox["Notebook styles", "BF"],
  " apply to the entire notebook. This is the best place for custom headers \
and other printing options, as well as background color and other options \
that apply to the entire notebook or every cell in every environment. This \
should actually be the first item listed in all the style sheets and will be \
resolved in Version 3.5."
}], "Item"],

Cell[TextData[{
  StyleBox["Inline styles", "BF"],
  " (which appear in HelpBrowser.nb) apply options to text within a cell, and \
are perhaps the clearest example of inheritance. The options specified in the \
inline style are added to the options already applied to the cell as a whole. \
An inline style could be as simple as something which applies bold face to a \
word. If the cell style already makes the text bold, the inline style is \
redundant and won\[CloseCurlyQuote]t have any effect. Here is a sample of an \
",
  ButtonBox["inline style",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "InlineSample.nb", CharacterEncoding -> "WindowsANSI"], None}
      ,
    ButtonStyle->"Hyperlink"],
  ". Change the environment to Printout and see how the styled text changes. \
Inline styles allow you to specify format changes for different environments, \
which makes them more useful than merely applying the particular option using \
the format menu."
}], "Item"],

Cell[TextData[{
  StyleBox["Format type styles", "BF"],
  " actually set the font for Input and Output. This is allows control of \
Standard and Traditional forms. The appearance of unformatted expressions is \
set here as well."
}], "Item"]
}, Closed]],

Cell[CellGroupData[{

Cell["Options of Note", "Subsection"],

Cell[CellGroupData[{

Cell["Cell Styles", "Subsubsection"],

Cell[TextData[{
  "Open a style sheet to explore: ",
  ButtonBox["Default.nb",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "Default.nb", CharacterEncoding -> "WindowsANSI"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  "Most header styles incude ",
  StyleBox["CellGroupingRules", "MR"],
  " which determine the grouping heirarchy when Automatic grouping is in \
effect. The first argument determines the grouping type, the second is the \
number determining status. The higher the number the lower the item falls in \
the heirarchy. See the section below called ",
  ButtonBox["Interesting Examples",
    ButtonData:>"Examples",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Most header styles also include autonumbering options, which control the \
values of autonumber objects within each of the different sections levels. \
See the section below called ",
  ButtonBox["Interesting Examples",
    ButtonData:>"Examples",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "As noted above, any style that should not appear in the style menu \
requires the option: ",
  StyleBox["StyleMenuListing->None",
    FontFamily->"Courier"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline and Hyperlink Styles", "Subsubsection"],

Cell[TextData[{
  "Open a style sheet to explore: ",
  ButtonBox["HelpBrowser.nb",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "HelpBrowser.nb", CharacterEncoding -> "WindowsANSI"], None}
      ,
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
Inline styles are named with short names since they tend to get \
used in abundance (and thus save on file space). Note that most inline styles \
apply only a small number of options, for minor changes to words within cells \
that are already defined with a options from the cell style.\
\>", "Text"],

Cell["\<\
Hyperlink styles are really inline cell styles which perform a \
specific button function (as well as define the look of the hyperlink item). \
We provide link styles that point to the different areas of the online help. \
I discuss issues regarding documents in the online help system in my second \
talk (2.HelpBrowser.nb).\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Format Types Styles", "Subsubsection"],

Cell[TextData[{
  "Open a style sheet to explore: ",
  ButtonBox["Default.nb",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "Default.nb", CharacterEncoding -> "WindowsANSI"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
These styles are defined in the Default stylesheet and usually \
nowhere else. That means an given stylesheet will have no listing for these. \
If you want to change them, you have to copy them out of the Default styles \
into your new stylesheet.\
\>", "Text"],

Cell[TextData[{
  StyleBox["CellExpression", "Text",
    FontWeight->"Bold"],
  " is the format for unformatted cell expressions"
}], "Item"],

Cell[TextData[{
  StyleBox["InputForm",
    FontWeight->"Bold"],
  ", ",
  StyleBox["OutputForm",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StandardForm",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["TraditionalForm",
    FontWeight->"Bold"],
  " define the look of these different forms when entering input (and getting \
output) into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Item"],

Cell[TextData[{
  StyleBox["InlineCell",
    FontWeight->"Bold"],
  " controls the look of an inline math cell expression, and ",
  StyleBox["InlineCellEditing",
    FontWeight->"Bold"],
  " controls the appearance of such a cell when the user edits the cell \
manually."
}], "Item"]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder and Palette Styles", "Subsubsection"],

Cell["\<\
Just some arcane stuff for the typesetting and button mechanisms, \
defined in the Default stylesheet and usually not redefined anywhere else. \
Best to leave these as they are.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Interesting Examples", "Subsection",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell["Invisible Cell", "Subsubsection"],

Cell[TextData[{
  "It\[CloseCurlyQuote]s possible to make cells dissappear, but it\
\[CloseCurlyQuote]s dangerous, because you can\[CloseCurlyQuote]t get at them \
easily once you do it. Handy for hiding things in print. ",
  ButtonBox["Closed Cell Sample",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "InvisibleCells.nb", CharacterEncoding -> 
        "WindowsANSI"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(CellElementSpacings -> {"ClosedCellHeight" -> 0}, \n
    CellOpen -> False\)], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cell Grouping Trickery", "Subsubsection"],

Cell[TextData[{
  "Hidden input with button access (Calc Wiz). ",
  ButtonBox["Hidden Input Button",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "HiddenInput.nb", CharacterEncoding -> 
        "WindowsANSI"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Autonumbering Demo", "Subsubsection"],

Cell[TextData[{
  "Autonumbering and references examples. ",
  ButtonBox["Autonumbering",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "Counters&Refs.nb"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Self-indexing Runningheads", "Subsubsection"],

Cell[TextData[{
  "Pseudo self-indexing runningheads. ",
  ButtonBox["Self-indexing Runningheads",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "Rhdemo.nb"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["New Features of Interest", "Section"],

Cell[TextData[{
  "Expanded inline cell capability: ",
  ButtonBox["InlineCellDemo",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "InlineCellsDemo.nb", CharacterEncoding -> "WindowsANSI"], 
      None},
    ButtonStyle->"Hyperlink"]
}], "Item",
  CellMargins->{{Inherited, Inherited}, {Inherited, 12}}],

Cell[TextData[{
  "Hyphenation (and spell checking \[LongDash] they go hand-in-hand since \
they both require dictionaries): ",
  ButtonBox["Hyphenation",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "HyphenationDemo.nb", CharacterEncoding -> "WindowsANSI"], 
      None},
    ButtonStyle->"Hyperlink"]
}], "Item"],

Cell["\<\
A number of new printing options, particularly helpful for \
adjusting page sizes and runningheads. Some of these new options are:\
\>", 
  "Item"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004d0000L1000`40O003h00Oogoo=Goo003oOole
Ool004Moo`<009moo`03001oogoo04Qoo`00BWoo00<007ooOol0WGoo00<007ooOol0Agoo000EOol4
0004Ool40003Ool500001Goo00000000Ool00`000goo0P000Woo0`000Woo00@007ooOomoo`<000=o
o`@000=oo`D0009oo`@000Eoo`8000=oo`@000=oo`<00003Ool007oo00=oo`8000=oo`D000=oo`<0
009oo`<00003Ool0000000@00005Ool00000001oo`03000017oo001oogoo10000Woo0P000Woo0P00
0Woo10005goo100017oo0`0000Aoo`00Oomoo`D0009oo`@000Aoo`<000Eoo`03001oogoo04Moo`00
5Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool01000Oomoo`000goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00@007ooOol000=oo`03001oogoo009oo`05001oogooOol00004
Ool01000Oomoo`0017oo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol00002Ool0
1`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo0003Ool01@00
Oomoogoo00003goo0P001Woo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo009oo`05
001oogooOol00002Ool01@00Oomoogoo000017oo00<007ooOol0Agoo000FOol00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007oo0000
17oo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo00Ioo`05001oogooOol00006Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomo
o`00009oo`05001oogooOol00002Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oo`0000Qoo`03001oogoo00moo`8000Aoo`03001oogoo00=oo`05001oogooOol0
0005Ool00`00Oomoo`06Ool01000Oomoo`0027oo00<007ooOol0Agoo000FOol40004Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00goo10000goo1@0000=oo`00
Ool00Woo00<007ooOol00goo00<007ooOol00goo0`0017oo00<007ooOol017oo00<007ooOol00goo
100017oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol00002
Ool01@00Oomoogoo00000Woo100017oo00<007ooOol00goo0P001Woo0`002Woo1@001Goo0P000Woo
00<007oo000017oo10001Goo00<007ooOol00goo0`000goo1@001Goo00<007ooOol0AWoo000FOol0
1@00Oomoogoo00000goo0P001Woo00<007ooOol00Woo0P000Woo00D007ooOomoo`0000Eoo`05001o
ogooOol00002Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=oo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Oomoo`04Ool20003Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<0
07ooOol00Woo00D007ooOomoo`00009oo`80009oo`04001oogoo0003Ool00`00Ool00003Ool00`00
Oomoo`02Ool20004Ool00`00Ool00004Ool01@00Oomoogoo00004Goo0P0017oo0`000goo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo000017oo00<007oo
Ool0Agoo000@Ool00`00Ool00003Ool01@00Oomoogoo00000Woo0P0000=oo`0000000Woo0`000goo
0P0000=oo`0000000goo10000goo00D007ooOomoo`0000=oo`<000=oo`D0009oo`<000Eoo`<000=o
o`@000=oo`800003Ool00000009oo`<000Aoo`@000=oo`<000Eoo`<0009oo`800003Ool0000000=o
o`05001oo`00Ool00002Ool30004Ool200000goo00000002Ool00`00Oomoo`020003Ool30004Ool0
0`00Ool00009Ool20006Ool00`00Ool00004Ool30006Ool00`00Oomoo`03Ool30004Ool30005Ool0
0`00Oomoo`17Ool0011oo`03001oo`0000=oo`05001oogooOol0000HOol00`00Oomoo`03Ool01@00
Oomoogoo00007goo00<007ooOol04Woo00<007ooOol067oo0P0000=oo`00000047oo00<007ooOol0
37oo00<007oo00004Goo00D007ooOomoo`0000]oo`03001oogoo019oo`03001oogoo04Moo`0047oo
00<007oo00000Woo1@0037oo00<007ooOol02Woo00<007ooOol00Woo1@004goo00<007ooOol02Woo
00<007ooOol04Woo00<007ooOol01Goo00<007ooOol03goo0P000goo0P003Woo0P003Woo00<007oo
000047oo1P002Goo0`004goo00<007ooOol0B7oo003oOoleOol00?moocEoo`00ogoo=Goo003oOole
Ool00?moocEoo`00ogoo=Goo000MOol3001:Ool3000ZOol00`00Oomoo`2>Ool00`00Oomoo`09Ool0
021oo`03001oogoo04Yoo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo04]oo`03001oogoo
00=oo`03001oogoo009oo`003Woo100017oo0`0000Aoo`00Oomoo`@000Aoo`<0009oo`@000Eoo`<0
00Aoo`<000Eoo`8000Aoo`<000=oo`@0009oo`<00005Ool00000001oo`03000017oo001oogoo1000
0goo10000goo1@0000Eoo`00000007oo00<00003Ool00000008001=oo`04001oogooOol3000017oo
000000000Woo0P0000=oo`0000000goo0P0017oo0`000Woo1`0000Ioo`00000007oo0004Ool20003
Ool50003Ool30005Ool00`00Oomoo`08Ool3000017oo000000000Woo0P0000=oo`0000000goo0P00
17oo0`000Woo1`0000Ioo`00000007oo0004Ool20003Ool50003Ool30005Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo
00D007ooOomoo`00009oo`03001oogoo00Aoo`05001oogooOol00002Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`05001oogooOol00003Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00D007ooOomoo`0000Qoo`8000Qoo`03001oogoo009oo`05001oogooOol00002Ool0
0`00Oomoo`020003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`07001oo`00Ool007oo0000
0goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`05001oogooOol0000@Ool01@00
Oomoogoo00000Woo00<007ooOol00P000goo00@007ooOol0009oo`05001oogooOol00002Ool01`00
Ool007oo001oo`0000=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol027oo000?Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00002Ool01@00Oomoogoo
00000goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00goo00L007ooOomoo`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00D007oo
Oomoo`0000Ioo`03001oogoo00Qoo`8000Ioo`03001oogoo009oo`D0009oo`05001oogooOol00003
Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00L007oo001oo`00Ool00003Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0BOol50002Ool01@00Oomoogoo00000goo
00<007ooOol00goo00D007ooOomoo`00009oo`07001oo`00Ool007oo00000goo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol027oo000?Ool40003Ool4
0002Ool01@00Oomoogoo00000goo1@000Woo00<007oo000017oo00D007ooOomoo`00009oo`05001o
ogooOol00003Ool00`00Oomoo`03Ool50003Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo1000
17oo00<007ooOol00Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`05001oogooOol00003Ool3
0003Ool50005Ool20003Ool00`00Oomoo`04Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<0
07ooOol00goo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool40004Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`0COol00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol0
0goo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool40004Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`07Ool00`00Oomoo`07Ool000moo`07001oogooOol007oo00000goo00@007oo
Ool000=oo`05001oogooOol00003Ool00`00Oomoo`030004Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000=oo`03001oogoo00=oo`05001oogooOol00003Ool20004Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo009oo`8000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool20002Ool01000
Oomoo`000goo00<007ooOol027oo0P001Woo00<007ooOol00goo00<007oo00000goo00D007ooOomo
o`0000=oo`03001oogoo00=oo`05001oogooOol00002Ool01`00Ool007oo001oo`0000=oo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol0000AOol00`00Ool00003Ool0
1@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`00009oo`07001oo`00Ool007oo0000
0goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Qoo`003goo00D007ooOomoo`00009oo`<000Aoo`D000=oo`<000=oo`03001oo`0000Eoo`<0
00Aoo`<000=oo`@000Aoo`<000=oo`800003Ool00000009oo`05001oo`00Ool00002Ool30004Ool2
00000goo00000002Ool50002Ool30003Ool200000goo00000004Ool30009Ool20008Ool00`00Oomo
o`04Ool01000Oomoogoo0P000Woo0P000Woo100017oo0`000Woo0`0000=oo`00Ool00Woo0`0017oo
10000goo0`001Goo0`004goo00@007ooOomoo`80009oo`80009oo`@000Aoo`<0009oo`<00003Ool0
07oo009oo`<000Aoo`@000=oo`<000Eoo`<000Eoo`03001oogoo00Qoo`003goo00D007ooOomoo`00
01Moo`05001oogooOol0000AOol00`00Oomoo`0AOol200000goo0000000lOol00`00Oomoo`04Ool0
0`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`0QOol00`00Oomoo`0:Ool00`00Oomoo`0IOol0
0`00Oomoo`0COol00`00Oomoo`08Ool000ioo`D001Moo`H0015oo`03001oogoo011oo`8000=oo`80
01Qoo`03001oogoo025oo`03001oogoo009oo`8000aoo`03001oogoo01Uoo`03001oogoo00Eoo`03
001oogoo01Qoo`8000aoo`03001oogoo01Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo
00Uoo`00ogoo=Goo003oOoleOol00?moocEoo`00ogoo=Goo003oOoleOol00?moocEoo`007Goo0`00
BWoo0`00:Woo00<007ooOol0SWoo00<007ooOol02Goo000POol00`00Oomoo`1:Ool00`00Oomoo`0V
Ool00`00Oomoo`12Ool00`00Oomoo`1;Ool00`00Oomoo`03Ool00`00Oomoo`02Ool000ioo`@000Ao
o`<00004Ool007ooOol40004Ool30002Ool3000017oo000000000Woo0`000goo0`0000Aoo`00Oomo
o`D000=oo`<000=oo`@0009oo`<00005Ool00000001oo`03000017oo001oogoo10000goo10000goo
1@0000Eoo`00000007oo00<00003Ool00000008001=oo`04001oogooOol3000017oo000000000Woo
0P0000=oo`0000000goo0P0017oo0`000Woo1`0000Ioo`00000007oo0004Ool20003Ool50003Ool3
0005Ool00`00Oomoo`08Ool3000017oo000000000Woo0P0000=oo`0000000goo0P0017oo0`000Woo
1`0000Ioo`00000007oo0004Ool20003Ool50003Ool30005Ool00`00Oomoo`04Ool00`00Oomoo`01
Ool000moo`03001oogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00D007ooOomo
o`00009oo`05001oogooOol00002Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Eoo`07001oogooOol007oo00000goo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000Eoo`03001oogoo009oo`05001oogooOol00002Ool01@00
Oomoogoo000027oo0P0027oo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo008000=o
o`04001oogoo0002Ool01@00Oomoogoo00000Woo00L007oo001oo`00Ool00003Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol00Woo00D007ooOomoo`00011oo`05001oogooOol00002Ool0
0`00Oomoo`020003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`07001oo`00Ool007oo0000
0goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`08Ool000moo`03001oogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00<0
07ooOol017oo00D007ooOomoo`00009oo`03001oogoo00=oo`05001oogooOol00002Ool01@00Oomo
ogoo00000goo00<007ooOol01Goo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00D007ooOomoo`0000Io
o`03001oogoo00Qoo`8000Ioo`03001oogoo009oo`D0009oo`05001oogooOol00003Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0BOol50002Ool01@00Oomoogoo00000goo00<007ooOol0
0goo00D007ooOomoo`00009oo`07001oo`00Ool007oo00000goo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol027oo000?Ool40003Ool40002Ool01@00
Oomoogoo00000goo1@000Woo00D007ooOomoo`00009oo`D0009oo`@0009oo`05001oogooOol00003
Ool50003Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo100017oo00<007ooOol00Woo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`05001oogooOol00003Ool30003Ool50005Ool20003Ool00`00
Oomoo`04Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`00
009oo`05001oo`00Ool00002Ool40004Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0C
Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`00009oo`05
001oo`00Ool00002Ool40004Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool000moo`07001oogooOol007oo00000goo00@007ooOol000=oo`05001oogooOol00003
Ool00`00Oomoo`050002Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0003Ool01@00Oomoogoo
00000goo00@007ooOomoo`8000Aoo`07001oogooOol007oo00000goo00<007ooOol00Woo0P000goo
00D007ooOomoo`0000Eoo`03001oogoo009oo`80009oo`04001oogoo0003Ool00`00Oomoo`08Ool2
0006Ool00`00Oomoo`03Ool00`00Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00goo00D0
07ooOomoo`00009oo`07001oo`00Ool007oo00000goo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol00Woo00D007ooOomoo`00015oo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol027oo000?Ool01@00Oomoogoo
00000Woo0`0017oo1@000goo0`000goo00D007ooOomoo`0000=oo`<000=oo`<000Aoo`@000Aoo`<0
00=oo`800003Ool00000009oo`05001oo`00Ool00002Ool30004Ool200000goo00000002Ool50002
Ool30003Ool200000goo00000004Ool30009Ool20008Ool00`00Oomoo`04Ool01000Oomoogoo0P00
0Woo0P000Woo100017oo0`000Woo0`0000=oo`00Ool00Woo0`0017oo10000goo0`001Goo0`004goo
00@007ooOomoo`80009oo`80009oo`@000Aoo`<0009oo`<00003Ool007oo009oo`<000Aoo`@000=o
o`<000Eoo`<000Eoo`03001oogoo00Qoo`003goo00D007ooOomoo`0001Moo`05001oogooOol0000C
Ool00`00Oomoo`0?Ool200000goo0000000lOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomo
o`0IOol00`00Oomoo`0QOol00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`0COol00`00Oomo
o`08Ool000ioo`D001Moo`<00004Ool00000000AOol2000@Ool20003Ool2000HOol00`00Oomoo`0Q
Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0HOol2000<
Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00?moocEoo`00
ogoo=Goo003oOoleOol00?moocEoo`00ogoo=Goo003oOoleOol001eoo`<003Qoo`03001oogoo08io
o`03001oogoo04Qoo`0087oo00<007ooOol0=7oo00<007ooOol0@Woo00<007ooOol0Bgoo00<007oo
Ool00goo00<007ooOol0@Goo000>Ool40004Ool3000017oo001oogoo100017oo0`000goo10000goo
1@000Woo1@000goo0`004goo00@007ooOomoo`<00004Ool000000002Ool200000goo00000003Ool2
0004Ool30002Ool700001Woo00000000Ool000Aoo`8000=oo`D000=oo`<000Eoo`03001oogoo00Qo
o`<00004Ool000000002Ool200000goo00000003Ool20004Ool30002Ool700001Woo00000000Ool0
00Aoo`8000=oo`D000=oo`<000Eoo`03001oogoo00Aoo`03001oogoo041oo`003goo00<007ooOol0
0goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomo
o`0000Aoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo000027oo0P0027oo00<0
07ooOol00Woo00D007ooOomoo`00009oo`03001oogoo008000=oo`04001oogoo0002Ool01@00Oomo
ogoo00000Woo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool00Woo00D007ooOomoo`00011oo`05001oogooOol00002Ool00`00Oomoo`020003Ool01000Oomo
o`000Woo00D007ooOomoo`00009oo`07001oo`00Ool007oo00000goo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`17Ool000moo`03001oogoo
00=oo`05001oogooOol00002Ool01@00Oomoogoo00000goo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00goo00<007ooOol037oo0P001Woo00<007ooOol00Woo1@000Woo
00D007ooOomoo`0000=oo`03001oogoo00=oo`05001oogooOol00002Ool01`00Ool007oo001oo`00
00=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo019oo`D0009oo`05
001oogooOol00003Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00L007oo001oo`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`17
Ool000moo`@000=oo`@0009oo`05001oogooOol00003Ool50006Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool50002Ool50005Ool20003Ool00`00Oomoo`04Ool00`00Ool00003Ool0
1@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool4
0004Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Ool00003Ool01@00Oomo
ogoo00000goo00<007ooOol00goo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool40004Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`16Ool000moo`07001oogoo
Ool007oo00000goo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoogoo0`001Goo00<0
07ooOol00Woo00@007ooOol000=oo`05001oogooOol0000:Ool20006Ool00`00Oomoo`03Ool00`00
Ool00003Ool01@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`00009oo`07001oo`00
Ool007oo00000goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
015oo`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo
00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol0Agoo000?Ool01@00Oomoogoo00000Woo0`0017oo1@000goo0`00
0goo00<007ooOol017oo0`0017oo1@000goo0`002Goo0P0027oo00<007ooOol017oo00@007ooOomo
o`80009oo`80009oo`@000Aoo`<0009oo`<00003Ool007oo009oo`<000Aoo`@000=oo`<000Eoo`<0
01=oo`04001oogooOol20002Ool20002Ool40004Ool30002Ool300000goo001oo`02Ool30004Ool4
0003Ool30005Ool30005Ool00`00Oomoo`17Ool000moo`05001oogooOol0000GOol01@00Oomoogoo
00009goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol08Goo00<007oo
Ool02Woo00<007ooOol06Goo00<007ooOol04goo00<007ooOol0Agoo000>Ool5000IOol40004Ool0
0`00Oomoo`0QOol00`00Oomoo`02Ool2000<Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomo
o`0HOol2000<Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`18Ool0
0?moocEoo`00ogoo=Goo003oOoleOol00?moocEoo`00ogoo=Goo003oOoleOol001aoo`<0041oo`03
001oogoo08ioo`03001oogoo045oo`007Goo00<007ooOol0?Woo00<007ooOol0@Woo00<007ooOol0
Bgoo00<007ooOol00goo00<007ooOol0>Woo000>Ool40004Ool3000017oo001oogoo100017oo0`00
0goo10000goo10000goo1@000Woo1@000goo0`004goo00@007ooOomoo`<00004Ool000000002Ool2
00000goo00000003Ool20004Ool30002Ool700001Woo00000000Ool000Aoo`8000=oo`D000=oo`<0
00Eoo`03001oogoo00Qoo`<00004Ool000000002Ool200000goo00000003Ool20004Ool30002Ool7
00001Woo00000000Ool000Aoo`8000=oo`D000=oo`<000Eoo`03001oogoo00Aoo`03001oogoo03Uo
o`003goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo
00000goo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00002
Ool01@00Oomoogoo000027oo0P0027oo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo
008000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00L007oo001oo`00Ool00003Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00D007ooOomoo`00011oo`05001oogooOol0
0002Ool00`00Oomoo`020003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`07001oo`00Ool0
07oo00000goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`10Ool000moo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol037oo0P001Woo00<007ooOol00Woo1@000Woo00D007ooOomoo`0000=oo`03001o
ogoo00=oo`05001oogooOol00002Ool01`00Ool007oo001oo`0000=oo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo019oo`D0009oo`05001oogooOol00003Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00L007oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`10Ool000moo`@000=oo`@000=oo`05
001oogooOol00002Ool50003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool50002Ool50005Ool20003Ool00`00Oomoo`04Ool00`00Ool00003Ool01@00Oomoogoo
00000goo00<007ooOol00goo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool40004Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Ool00003Ool01@00Oomoogoo00000goo
00<007ooOol00goo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool40004Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0oOol000moo`07001oogooOol007oo0000
0goo00D007ooOomoo`0000=oo`04001oogoo0003Ool01000Oomoogoo0P001Goo0`001Goo00<007oo
Ool00Woo00@007ooOol000=oo`05001oogooOol0000:Ool20006Ool00`00Oomoo`03Ool00`00Ool0
0003Ool01@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`00009oo`07001oo`00Ool0
07oo00000goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00015o
o`03001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00L0
07oo001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol0@7oo000?Ool01@00Oomoogoo00000Woo0`000goo1@0017oo0`000goo
0P0000=oo`0000000Woo00<007ooOol017oo0`0017oo1@000goo0`002Goo0P0027oo00<007ooOol0
17oo00@007ooOomoo`80009oo`80009oo`@000Aoo`<0009oo`<00003Ool007oo009oo`<000Aoo`@0
00=oo`<000Eoo`<001=oo`04001oogooOol20002Ool20002Ool40004Ool30002Ool300000goo001o
o`02Ool30004Ool40003Ool30005Ool30005Ool00`00Oomoo`10Ool000moo`05001oogooOol0000N
Ool01@00Oomoogoo00009goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol06Goo00<007oo
Ool08Goo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol04goo00<007ooOol0@7oo000>Ool5
000POol40004Ool00`00Oomoo`0QOol00`00Oomoo`02Ool2000<Ool00`00Oomoo`0IOol00`00Oomo
o`05Ool00`00Oomoo`0HOol2000<Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`11Ool00?moocEoo`00ogoo=Goo003oOoleOol00?moocEoo`00ogoo=Goo003oOoleOol0
041oo`<001Uoo`<002Yoo`03001oogoo00Aoo`03001oogoo02aoo`03001oogoo01Aoo`03001oogoo
02aoo`03001oogoo00Aoo`03001oogoo02Eoo`00@goo00<007ooOol06Goo00<007ooOol09Woo00<0
07ooOol017oo00<007ooOol04Goo00<007ooOol06Woo00<007ooOol00goo00<007ooOol037oo00<0
07ooOol04Goo00<007ooOol06Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol07Woo000>
Ool40004Ool40003Ool500001Goo00000000Ool00`000goo0P000goo1@0000Eoo`00000007oo00<0
0003Ool000000080009oo`<00005Ool00000001oo`03000017oo001oogoo10000goo10000goo1@00
00Eoo`00000007oo00<00003Ool00000008001=oo`03001oogoo00Aoo`03001oogoo00=oo`<000Eo
o`<000Aoo`03001oogoo00Yoo`<000Eoo`<000Aoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo009oo`D000Aoo`03001oogoo00]oo`03001oogoo009oo`D000Aoo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo01eoo`003goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo0004Ool00`00Oomoo`02Ool01`00Oomo
ogoo001oo`0000=oo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol0
0008Ool20008Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol0
3goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00Aoo`03001o
ogoo009oo`05001oogooOol0000BOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
17oo00<007ooOol097oo000?Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo00<007ooOol01Goo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool01@00
Oomoogoo00000goo00<007oo00000goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00Eoo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`08Ool20006Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0TOol000moo`@000Aoo`03001oogoo00Eo
o`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01`00Oomo
ogoo001oo`0000=oo`05001oogooOol00003Ool00`00Oomoo`040004Ool00`00Oomoo`02Ool01@00
Oomoogoo00001Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`<000=oo`D000Eoo`8000=oo`03
001oogoo00Aoo`03001oogoo00=oo`05001oogooOol00002Ool5000@Ool01@00Oomoogoo00000Woo
1@001Goo00<007ooOol047oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol04goo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol08goo000?Ool01@00Oomoogoo0000
0goo0P001Woo00<007ooOol00Woo0P000Woo00D007ooOomoo`0000Moo`03001oogoo009oo`80009o
o`03001oo`0000=oo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`02Ool20003Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo0P000Woo00@007ooOol000=oo`03001oogoo00Qoo`80
00Ioo`03001oogoo00Aoo`03001oogoo009oo`@000=oo`04001oogoo000AOol40003Ool01000Oomo
o`001Goo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol04Woo00<007oo
Ool017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol097oo000?Ool01@00Oomoogoo0000
0Woo0P0000=oo`0000000Woo0`000goo0P0000=oo`0000000goo10000goo0`000goo0P0000=oo`00
00000goo1@000Woo00D007oo001oo`00009oo`<000Aoo`800003Ool00000009oo`D0009oo`<000=o
o`800003Ool0000000Aoo`<000Uoo`8000Qoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00Eoo`03001oo`00015oo`03001oogoo00Eoo`03001oo`0000Eoo`03001oogoo019oo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo02Aoo`003goo00D007ooOomoo`0001Qoo`03001oogoo01Qoo`800003Ool00000
03aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Ioo`80015oo`03001oogoo00Ioo`80
00Eoo`03001oogoo019oo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo000047oo
00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0TOol000io
o`D000aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00moo`8000=oo`8001Qoo`03001o
ogoo025oo`03001oogoo00Aoo`04001oogooOol50005Ool00`00Oomoo`0?Ool50005Ool00`00Oomo
o`02Ool00`00Oomoo`0DOol01000Oomoogoo1@000goo0`004Goo1@000goo0`0017oo00<007ooOol0
17oo00<007ooOol09Goo003oOoleOol00?moocEoo`00ogoo=Goo003oOoleOol00?moocEoo`00ogoo
=Goo000bOol3000:Ool3000iOol00`00Oomoo`2fOol003Eoo`03001oogoo00Qoo`03001oogoo03Mo
o`03001oogoo0;Moo`00100017oo10000goo1@0000Eoo`00000007oo00<000=oo`8000=oo`D00005
Ool00000001oo`0300000goo000000020004Ool20004Ool40005Ool20003Ool50003Ool30002Ool3
00001Goo00000000Ool010004goo00<007ooOol0]goo00000goo001oo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol000Aoo`03001oogoo009oo`07001oogoo
Ool007oo00000goo00D007ooOomoo`00009oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol00002Ool01@00
Oomoogoo000027oo0P0027oo00<007ooOol0]goo00000goo001oo`06Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol00Woo00L007ooOomoo`00
Ool00003Ool01000Oomoo`0017oo00@007ooOol000=oo`05001oogooOol00007Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`8000Ioo`03001oogoo
0;Moo`0000=oo`0000000P0017oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`03001oogoo00Eoo`03001oogoo009oo`07001oogooOol007oo00000goo00@007ooOol000Aoo`04
001oogoo0003Ool01@00Oomoogoo00001goo00<007ooOol00Woo00D007ooOomoo`00009oo`05001o
ogooOol00003Ool30003Ool50005Ool20003Ool00`00Oomoo`2hOol00003Ool007oo009oo`04001o
ogooOol20006Ool00`00Oomoo`02Ool20002Ool01@00Oomoogoo00001goo00<007ooOol00Woo0P00
0Woo00<007oo00000goo00@007ooOol000Aoo`04001oogoo0003Ool01@00Oomoogoo00001goo00<0
07ooOol00Woo00D007ooOomoo`00009oo`80009oo`04001oogoo0003Ool00`00Oomoo`08Ool20006
Ool00`00Oomoo`2gOol00003Ool007oo009oo`03001oogoo00800003Ool00000009oo`<000=oo`80
0003Ool0000000=oo`@000=oo`<000=oo`800003Ool0000000=oo`D00003Ool007oo00=oo`03001o
o`0000@000=oo`@000=oo`<000Eoo`<0009oo`800003Ool0000000Aoo`<000Uoo`8000Qoo`03001o
ogoo0;Moo`0000=oo`00Ool00Woo00<007ooOol05Woo00<007ooOol067oo00@007ooOol000]oo`03
001oogoo02moo`03001oogoo0;Moo`001@0037oo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool04Goo0P0037oo00<007ooOol01Goo00<007ooOol0:7oo00<007ooOol0]Woo003oOoleOol00?mo
ocEoo`00ogoo=Goo003oOoleOol00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{308, 112},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontFamily->"Courier"],

Cell[TextData[{
  StyleBox["PrintMargins", "BF"],
  " sets the outer margins around the text in relationship to the specified \
page size. \n\n",
  StyleBox["PaperSize", "BF"],
  " sets the size of the actual sheet of paper being printed, which comes \
from the print driver settings.\n\n",
  StyleBox["PageSize", "BF"],
  " set the desired page trim, and centers on the ",
  StyleBox["PaperSize", "BF"],
  ". The registration marks reflect the ",
  StyleBox["PageSize", "BF"],
  ".\n\n",
  StyleBox["PageHeaderMargins", "BF"],
  " and ",
  StyleBox["PageFooterMargins", "BF"],
  " adjust the position of the runningheads.\n\n",
  StyleBox["PrintRegistrationMarks", "BF"],
  " turns the page trim marks on and off."
}], "Text"],

Cell["\<\
We\[CloseCurlyQuote]re working on an interface for entering \
runningheads as simply as constructing cells in a notebook. We\
\[CloseCurlyQuote]re also planning something for entering page sizes and \
runningheads in a graphical interface. These will be made available as part \
of the Author Tools pack.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Authoring Tools", "Section"],

Cell[CellGroupData[{

Cell["Document Formatting Palettes", "Subsection"],

Cell[TextData[{
  "These are some palettes that have been created for ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " and internal use. They demonstrate some convenient formatting features. \
Stand alone versions of these will all be made available on the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " web sites."
}], "Text"],

Cell[TextData[ButtonBox["Scratch File",
  ButtonData:>{
    FrontEnd`FileName[ {"Files"}, "New.nb", CharacterEncoding -> 
      "MacintoshRoman"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[{
  ButtonBox["CellStyles",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "CellStyles.nb"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["InlineTextStyles",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "InlineTextStyles.nb"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ItemMaker",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "ItemMaker.nb"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Outliner",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "Outliner.nb"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Autonumbering\n",
    ButtonData:>{
      FrontEnd`FileName[ {"Files"}, "Autonumbering.nb"], None},
    ButtonStyle->"Hyperlink"],
  ButtonBox["Sample",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "Riemann.nb", CharacterEncoding -> "WindowsANSI"], None},
    ButtonStyle->"Hyperlink"],
  " file, ",
  ButtonBox["ReferenceMaker",
    ButtonData:>{"ReferenceMaker.nb", None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Template",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "TemplateFile.nb", CharacterEncoding -> "WindowsANSI"], None}
      ,
    ButtonStyle->"Hyperlink"],
  " file, ",
  ButtonBox["Template palette",
    ButtonData:>{
      FrontEnd`FileName[ 
      {"Files"}, "Template.nb", CharacterEncoding -> "MacintoshRoman"], None}
      ,
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Indexing Tool", "Subsection"],

Cell[TextData[
"Currently under development. The indexing palette offers a simple interface \
for adding index tags to your documents. It exploits an undocumented option \
called \[OpenCurlyDoubleQuote]TaggingRules\[CloseCurlyDoubleQuote] in order \
to provide detailed indexing information at the cell level, and it generates \
various types of indexes automatically."], "Text"],

Cell["Inquire with me about beta testing this.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Table of Contents Tool", "Subsection"],

Cell["\<\
Currently under development. A package for generating a TOC for one \
or a range of notebooks.\
\>", "Text"],

Cell["Inquire with me about beta testing this.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Bibliography Tool", "Subsection"],

Cell["\<\
Currently under development. A package for maintaining a personal \
database of cited reference material which also generates formatted \
bibliographies\
\>", "Text"],

Cell["Inquire with me about beta testing this.", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Publicon",
  FontSlant->"Italic"]], "Section",
  TextJustification->0],

Cell["\<\
The Comprehensive Solution 
for Technical Publishing\
\>", "Subsubsection",
  TextJustification->0],

Cell[CellGroupData[{

Cell["Description", "Subsection",
  TextJustification->0],

Cell[TextData[{
  "A word processing tool for paperless technical publishing. ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " offers flexible technical typesetting and heirarchical text structuring \
technology for disseminating electronic documents across all computer \
platforms."
}], "Text",
  TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ok, what is it really?", "Subsection"],

Cell[TextData[{
  "A customized version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packaged for the electronic technical document market."
}], "Text",
  TextJustification->0],

Cell[CellGroupData[{

Cell["Principle Value Factors", "Subsubsection",
  TextJustification->0],

Cell[TextData[
"User-friendly mathematical typesetting\nLive interface for both electronic \
display and print\nHeirarchical document structuring based on \n     \
openable/closeable text groups and multi\[Hyphen]faceted \n     document \
content\nFull hypertext implementation\nPalette/button\[Hyphen]driven input \
and formatting tools\nUniversal document portability, including \ngraphics \
portability\nStylesheets for document design"], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Demo Version", "Subsection",
  CellElementSpacings->{"ClosedGroupTopMargin"->24}],

Cell[TextData[{
  "Available for free on the web\nProvides access to all documents created in \
",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " \n     and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\nSupports all of the regular ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " document browsing \n     and navigation features\nSupports all of the \
regular ",
  StyleBox["Publicon",
    FontSlant->"Italic"],
  " document content\nUpgradable to save enabled, full version with a phone \
call"
}], "Text"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Web site:",
    FontWeight->"Bold"],
  StyleBox[" www.publicon.com",
    FontWeight->"Plain"]
}], "Subsection"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Presentation",
WindowSize->{602, 495},
WindowMargins->{{41, Automatic}, {Automatic, 0}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell["\<\
Below is a PICT header for use with all WWMC notebooks. Copy and \
paste this cell at the top of your notebook. \
\>", "Text"],
  
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:800006B000`400?l00000o`00003oo`00003o
000008X00000003o00000?l00000RP0000000?l00000o`00002:00000000o`00003o000008X00000
000:0000000>05eMG@2l_;`0jn_[0>c/k031`L407QhN0000000L71`0QXJ60<[:bP3[jn/0gmoO0:^[
Z`1ADE420000000;06UYJ@3GemL0e=CD055AD@0000009BDU0<S8b03De=@0bl_;01DE5@1RHV800P3F
e]H01P20P8000000000000000000JFUY0=KFeP80dM7A00h0dm?C0=KFeP16ATH0ATI60=CDe03EeMD0
TY:B00X:2P2b/[80e=CD0=WIf@1^KVh0HV9R0=KFeP80dM7A01d0dm?C0=SHf01PH600;2`/0=7Ad@3F
e]H0P820000000061PH0[Jf]0=GEe@3De=@0DE5A0000000=3@d0Ng]k0<c<c03]kNd0iNGU09bLW00@
4100`/;20=;BdP3AdM40d];B0=?Cd`3<[[@0/0HU0:l07P050:l080030:l07`2_01h0[`0O0080[`0P
0P2_01l0102d1B<0/P<S0;838`2b0b<20;838P<0/P<S00<0/P<R0;438@2b0b800P2b0b<30;838P@0
/P<S00<0/@<Q0;838P2b0b<00`2b0b<00`2a0b40/P<R0;838`0<0;838`030;838P2b0b<0/P<S0080
/P<S0P2b0b840;838`80/P<R0`2b0b<00`2b0b80/@<Q0;838P040;838`030;D3902F1Al03`l?0?l0
3`l?00<07QhN000000000000fP00000000T0000000<0Rh^;0?ooo`3oool00`3oool00`0T92@07alO
0=WIf@060?ooo`0307]kN`000000Ph>30080oooo00<0Hf=S0000002n_[h00`3oool01@0K6a/0O7al
0?ooo`3oool0WinO00<0000000<0QHF50?ooo`3oool00`3oool01P1IFET0F5QH0?ooo`3oool0/K6a
075aL@80oooo00<0h^;R01XJ6P1mOGd01@3oool01`1iNGT0>3Ph0?ooo`3oool0X:2P00000024Q8@0
0`3oool00`1SHf<01@D50;fm_@040?ooo`030=cLg00G5aL0m?Cd00@0oooo00<0nMOM0=L7;P3E02@0
1@3F02L01@3E0240f0/`0=L4:`3F02H0eP0W0080e`@Z00@0e`D/0=H1:03F02L0eP0W0P3G12X30=H0
9`090=D08@3H2c00e`@[0=H09P3F02L0e`L]0=D08P3G0bX0eP<Y0080eP0W00X0e@0S0=P9;`3F0BL0
eP0U0=H09`3F02P0e@0R0=L9;P3F0BP0eP0U303F02L0203G1R`0eP4X0=H09`3F02L0eP0V0=L6;03F
0RP0eP0V0P3F02L00`3F02H0e`L]0=H09`030=H09`030=H09@3H3C80eP0U00D0eP0W00<0]`0Q0000
00000000oP0000000`0;2`/000000000003J00000000200000002@0h>3P0oOgm0?ooo`3oool0alO7
09BDU037alL0=3@d09bLW0020?ooo`030>KViP2FUYH0^[Zj0080oooo00<0oOgm024Q8@1gMgL00P3o
ool00`1EEED0H61P0?ooo`020?ooo`030?Shn00J6QX0N7Qh0080oooo00D0Z:RX01`L700L71`00000
07moO`020?ooo`050<30`01KFe/0GemO01XJ6P1NGUh00P3oool01`3Jf]X0k>c/0?ooo`3_knl0@d=3
00000021PH400P3oool01@30`<00Fe]K065QH@0V9RH0@T920080oooo00<0T92@034a<@3kno/00`3o
ool04@1FEUH0GemO0?ooo`3oool0o_kn0;6a/@2HV9P0_Kfm01hN7P3/k>`0oooo0?[jnP1iNGT0FEUI
071?E@3A0R40eP0V00@0eP0W00`0e@0O0>=CK@3d^L@0fado0=D08`3D01d0iF1g0>ELM@3/QYP0fQTl
0=D08`3D01d20>IQN@0I0=@07@3F02L0e@0O0>=CK@3d^L@0fado0=D08`3D01d0jG>80>f>X03aZKL0
fADi0=D08`3E0200gRi>0?Fob@3YN8d0eP8T0=H09P3E0200gBm?0?G0bP3^UJH0ePDW0=H09@090=H0
9`0F0=H09@3G0bX0kYFU0=XH>`3E02<0eP0W0=D08@3M;dl0jWjB0=D08P3F02H0eP0W0=@07@3TFG80
iEae0=@07P3F02L0e00O0>AJL`3c]l80i5Yc0=@07`@0eP0W00<0/@0P000000000000oP0000000`0?
3`l000000000003J00000000200000003`2>SXh0oooo0?ooo`34a<@02`/;0000000<30`08R8R0>CT
i03oool0o?cl04a<C00000000P820;Zj^P020?ooo`0<06=SH`1_Kfl0oooo0?Win@2@T900i>CT0?oo
o`3bl_80oooo0?Shn00J6QX0N7Qh0P3oool01@3inOT0k^k^0>7Qh@000000Ng]k0080oooo00D0k^k^
0=;BdP35aLD00000061PH0050?ooo`040=?Cd`0d=3@000000820P080oooo00D0k^k^0=;BdP34a<@0
000004E5A@020?ooo`080:6QX@32`/80oooo0>c/k03kno/0oooo06EUI@2h^;P20?ooo`0<09:BTP00
0000000001XJ6P0F5QH0kno_0?ooo`3no_h0f][J0=;BdP24AE40`00E103F02L03@3F02@0e`d`0?G4
c@3O=eH0e@4T0=H09`3D01/0ifb20?6Y]P3d_LL0fQPk0=D08`3D01`00P3YL8H06@3D01`0eP0T0=L=
<03ea<d0gcMF0=D1903F02L0e00L0>AJL`3ieM`0lkG10=L4:@3F02D0e00L0>b8VP3_UjL0mKo90=TC
=`3E02<0e00L0>fAXP3XLHL0l:Bb0>51G`3D01l02@3F02L05P3F02D0e`<Z0?:]^@3J73l0e@0S0=H0
9`3E0240iF1h0?WIg`3J6ch0e@0R0=H09P3F12H0kiJV0?Bja@3F0bH0eP0U0=@07`3ZP9@0l[6n0>^1
U@3D01l40=H09`030;408000000000000?h0000000<03`l?000000000000fP00000000P0000000@0
Vi^K0?ooo`3oool0YJFU0`0000001@0@4100l?3`0?ooo`3jn_X0<C4a0080000000<0YZJV0?ooo`3o
ool00P1^KVh02P3oool0n_[j0?;blP3oool0alO70;fm_@3oool0n?Sh01XJ6P1hN7P20?ooo`050?Ge
m@3Vi^H0emOG0000001lO7`0103oool00`3dm?@00@4105mOG`020?ooo`070>3Ph02[Zj/0moOg0?oo
o`3Zj^X04a<C07UiN@040?ooo`030?Cdm0030`<0@d=30080oooo00P0kno_0?ooo`3QhN40Xj>S0?gm
o@3oool0JFUY0<C4a080oooo00H0JFUY0000000000000000010@403`l?040?ooo`0309mDH@2m01D0
eP0W00<0eP0W00d0e@0S0=TC=`3gb]80f0db0=D08P3F02L0e00K0>IWO`3e`l`0m/SA0=TE>@3E02<0
e00L0080j6j301T0e00L0=D08`3I4cL0ml[B0=P=<P3E0280eP0W0=D08P3L8T@0nMOM0>YmT@3D01`0
eP0V0=@07P3^UJH0jWfA0>MXOP3G22d0e@0U0=@07P3_VZX0he=]0>jFYP3SCf/0e00N00T0eP0W01H0
eP0U0=L1:03aY[@0fQ/n0=D08`3F02@0f0/`0?:/^@3b[k/0i5E_0=@07P3E0240gS1@0?>g`@3d^lD0
fQLl0=D08`3D01/0iEYd0?_Xk03UFg@0e00K103F02L00`2a020000000000003n0000000300l?3`00
000000000=X0000000080000000905IFEP3oool0oooo0?KfmP1eMGD0ATI608Z:RP0g=cL0^KVi0080
oooo00@0bl_;05YJFP2:RXX0n?Sh0P3oool00`0i>CT0M7Ad0?ooo`020?ooo`070?;blP0l?3`0a/K6
0?ooo`3hn?P06QXJ07QhN0020?ooo`050;Ng]`14A4@0ADE500X:2P1mOGd00P3oool01@2d];@0>c/k
03/k>`000000HV9R0080oooo00<0/[:b01hN7P3Shn<00P3oool01@0e=CD0M7Ad0?ooo`3oool0];Bd
0080>c/k00<00P8204I6AP3oool00`3oool01P1OGel0SHf=0?ooo`3oool0FEUI0861P@80oooo00d0
g]kN05YJFP1;Bd/0TY:B01lO7`3/k>`0oooo0?[jnP1OGel0>SXj04/]<`3=01/0eP0V00<0eP0W00d0
eP0V0=D18@3ZNi00lk>n0=TF>@3E02<0e00L0>M]P`3WJX40kiVX0=XL?`3E02<0e00L0080j6n401T0
e00L0=H09P3E0B40jW^@0?>c_P3I5ST0e@0S0=H0903G12X0n=3G0>AJM03D01`0eP0W0=@07@3RBfL0
mlWA0>YhS@3F0RD0eP0V0=@07P3QAV<0mlWB0?:_^`3H3S00e@0T00T0eP0W01H0e@0S0=XH?03fbM80
fQPk0=D08`3F02D0eP@W0>j@X@3c]l80gRi>0=D08@3E02<0fQTk0?:^^`3aYK<0e``^0=D0903D01`0
i5Uc0?O@f03TFG<0e00L103F02L00`2a020000000000003n0000000300l?3`00000000000=X00000
00080000000300H61P2k^k/0oooo00@0oooo00<08b<S04A4A03gmoL01P3oool00`2d];@00@4107em
O@030?ooo`070861P@000000e=CD0?ooo`3hn?P06QXJ07QhN0020?ooo`050?KfmP3Vi^H0j>SX04U9
B@1bLW800P3oool01@3^k^h0d];B0=CDe00_;bl0FUYJ0080oooo00L0mOGe0>KViP3oool0oooo0>7Q
h@0=3@d0NWYj0080oooo00D0kno_0=;BdP3De=@0<S8b03hn?P030?ooo`030;bl_0000000VIVI0080
oooo00<0G5aL01HF5P3Vi^H0103oool02P3Kfm/05aLG0>c/k03oool0o_kn0=_Kf`3AdM40f;Fl0=L5
;03E02@40=H09`040=H09@3F02L0gS9A0=P:<080eP0U00H0fADh0=XF>@3K7T00e`D[0=H09P3F02D2
0=XE>@070=H09@3F02L0eP0U0=H09`3N<U80f0X`0=H09@020=H09`030=`Q@`3H3C80eP0U0080eP0W
00@0eP0T0=h`C`3J63`0eP0T0P3F02L0103E02@0gRm>0=XH?03E02<:0=H09`0:0=H09@3H3340gS1@
0=L3:P3F02H0eP0W0=D08`3I53P0gBU:0=D08`80eP0W00X0e@0T0=`RA03J6ch0e@0T0=H09`3F02H0
e`@[0=dZB`3G12/0eP0V103F02L00`2a020000000000003n0000000300l?3`00000000000=X00000
00090000000;01<C4`2QXJ40lo?c0?knoP3oool0l?3`02PX:0000000@d=30<G5a@3kno/00P3oool0
4@3/k>`0UiNG00T92@000000NGUi0?gmo@3lo?`0`L7100d=3@030`<0f][J0?gmo@3emOD0410@07al
O03oool0oOgm00<0oooo00@0BTY:06UYJ@3moOd0oOgm0`3oool0100b<S80Cdm?0?gmo@3lo?`20?oo
o`070?knoP3Cdm<0BTY:0000001jNWX0oOgm0?knoP030?ooo`0803De=@0d=3@0oooo0?ooo`3_knl0
8R8R0000002FUYH20?ooo`0505]KF`0000009BDU0;Fe]@3emOD00P3oool00`3<c<`05QHF0>[ZjP02
0?gmo@80oooo00L0n=?J0=P1:03D01l0eP0Q0=L08`3G0280e@0R0080e`0R00`0e00I0=D0803G0280
e@0R0=D07P3F01h0e`0J0=P07`3G0280e@0R0=D07P3G01h20=D08P0?0=P08@3G0240eP0J0=D0803E
0280e`0R0=L08`3E01/0e@0O0=P08P3H0240e@0R0=D08@3D01X0e@0N0080e`0R00T0e@0R0=D08@3F
01P0e`0L0=D08P3H0240f00P0=L08P3E02800P3F02820=D08P80f00P00T0f00Q0=D0803D01T0e`0Q
0=H08P3E0280f00R0=H07`3F01X00P3E0280103H0240e`0S0=H06P3G01/30=D08P060=H0803D01X0
e@0P0=P08@3H0200f00Q0P3E02800`2b01`000000000003n0000000300l?3`00000000000=X00000
000;0000000<04E5A@2c/k<0_[jn071`L0061PH08R8R05IFEP1]KFd0K6a/05UIF@1=CDd09BDU0P00
00004`0n?Sh0SHf=0;jn_P2DU9@0>3Ph000000010@40>c/k09ZJVP2OWil0H61P01`L701`L700XZ:R
0:2PX02FUYH0N7Qh07IfMP1lO7`00P2PX:006`2NWYh0HF5Q09FEU@1_Kfl0MWIf0::RXP2CTi<0L71`
0451@@0_;bl03@d=000000051@D0MWIf0::RXP2?Shl0?clo04a<C02MWId0LG5a05MGE`0o?cl0@410
02/[:`0o?cl0HF5Q08R8R002061PH00:07YjNP1PH600F5QH06MWI`23Ph<0NWYj04];B`0W9bL02PX:
09FEU@@0X:2P02<0SHR906U<DP1eEEX0K4aA03853@1B8RX0M5eR04XN9P0e1@h0LU1F07EEFP1_CeD0
MUEJ07IEF`1WAT`0>1HL02X:401G>d00MeIK07=CF01PADT0Le=H07IIGP1F:340=@D<04dP:01eFEh0
M5QM04DL900e1@h0KdiD07MGG@1F=cd0DRP_07IHG@0307EDFP0/06I9CP1OA4P0MUEK079>E00f31<0
BB0W07ELH@1C9Bd0<`/B06]9C`1fEE/0L51F07EDF@1fEE/0Kd]B02l<4P0Z2@h0DBD]07IIGP1fEEX0
F3m306i?E01gEU/0HDA903D53P1;7RH0MEUN07IIGP1F:340=@D=02h83`1D5B00PeUQ08iVK@1_CeD0
KTmD07IEFP1dEe`0?A`R02X93@0o7B<0MEQM07IEFP1G?T;o00000040000000<03`l?000000000000
fP00000000/0000000H0N7Qh0?gmo@3moOd0]kNg0000002<S8`20?ooo`060;>c/`00000000000000
000a<C40_;bl0`3oool03P3moOd0g]kN075aL@00000010@40>g]k@3moOd0lo?c018B4P38b<P0oOgm
0?ooo`22PX80LW9b0P3oool01@3no_h0oooo0?clo01?Cdl0h>3P00<0oooo00@0o_kn0>_[j`2VYZH0
6QXJ0P0000002P18B4P0o_kn0?gmo@3YjNT000000492@P3lo?`0oooo0>o_k`0820P2000000030;no
_`3oool0oooo0080C4a<103oool01P3moOd0fMWI07EeM@00000030`<0>k^kP80oOgm0P3oool08P39
bl/0KWEc0:ji]`2V];401PD505ADE02__;X0HV9R0000002LZ:H0[kZh0828Q`29TY00[kZh0:>]Z`17
BDP0<cDd08J>S@2_^[P0Yk6`05QNG@2W/K00[kZh06E/JP000000:b/[0:jj^02_^kT0>SXj0000002?
VYP0[kZh06ieL`0m@3l20:nj^080/;^i0180VZBR05eSHP2_^[P0[;Ne01LH600m@3l0[kZh07MnO@00
0000Qi2>0:nj^02=UY@0OXF40:nj^02Z]K<0AdY9030b<P1iP7h20:nj^00@04M<B`2FX9h0[kZh08fH
UP0000009bLW0:fi]`2_^[P0I6]Z0000000j>SX0WJJU0:nj^02`^kT0Z[Fc08F=R`80[kZh00<0HFMV
02`^;P1NHf800P2_^[P00`1UK6/000000000003n0000000300l?3`00000000000=X00000000:0000
000700D51@3Fe]H0oooo0?ooo`3/k>`051@D0;Ng]`020?ooo`050?KfmP0X:2P0000000h>3P3De=@0
0`3oool02P3bl_80oooo0?ooo`3oool0FUYJ00@4103`l?00oooo0>SXj02:RXX20?ooo`030<c<c009
2@T0NWYj00<0oooo00L0o_kn0?_kn`1GEeL0i>CT0?ooo`3no_h0lO7a00<0oooo00@0b<S800H61P00
0000WIfM0`3oool00`0j>SX0N7Qh0?ooo`020?ooo`0405mOG`00000000000;Rh^080oooo0P1EEED2
0?ooo`030?Win@3dm?@0oooo0080oooo01@0KFe]00820P3`l?00oooo0?knoP3<c<`0`L7109FEU@0n
?Sh0/K6a0;:b/P0n@400K6e]0;:b/P2WZ:P07b0P08j>SP2b/[80MgMg03dm?@H0/[:b0240Xj>S02DU
9@2XZ:P0/[:b08>3P`00000051@D0:b/[02b/[80FU]K0000001bLW80/[:b09>CT`0_;bl0[jn_0;:b
/P2VYZH0QhN707emO@0j>SX0[Jf]0;:b/P1=CDd0FEUI0;:b/P2_[jl0:b/[07UiN@2b/[80S8b<034a
<@2`/;001@2b/[80302][Jd092@T08J6QP2b/[80Z:RX00P92@0A4Q80[:b/0;:b/P1oOgl04a<C0:>T
Y080/[:b00@0[Zj^0:n_[`1VIVH0U9BD1P2b/[800`19BDT000000000003n0000000300l?3`000000
00000=X00000000:0000000703dm?@3no_h0oooo0?ooo`3moOd0E5AD0=cLg0030?ooo`0308Z:RP00
0000KVi^0080oooo00@0i>CT04Y:BP0_;bl0ZJVY0P3oool01@3:b/X04a<C0>c/k03oool0oOgm0080
oooo00@0l?3`0410@0000000PH610P3oool02P2e]KD0@41003lo?`0Q8B40kNg]0?ooo`3inOT0BTY:
05UIF@3_knl20?ooo`0303hn?P071`L0i>CT00<0oooo00<0Ng]k0:6QX@3oool00P3oool01035aLD0
0@410000002h^;P20?ooo`80EEEE0P3oool00`31`L40<C4a09VIV@020?ooo`0=0<c<c00G5aL0k>c/
0?ooo`3kno/0P82006QXJ00_;bl020P80:2PX02b/[80Jf][08B4Q0020;:b/P0@06UYJ@23Ph<0/[:b
07inOP0410@0T92@0;:b/P2][Jd0LG5a0:ZZZP2b/[80Rh^;00P8202IVIT0/[:b09bLW0800`<30180
WIfM0;:b/P2CTi<0GUiN096AT@2b/[80YZJV02DU9@2VYZH0/[:b09BDU018B4P0@T9200P8202>SXh0
/[:b07YjNP1gMgL20;:b/P0F07MgM`1dM7@0/[:b09>CT`020P80OWin0;:b/P2a/K40MgMg0:6QX@2b
/[80WinO00@4101`L700/[:b0;2`/00S8b<00@4109ZJVP2b/[80U9BD03Ti>@80/[:b00D0UiNG02XZ
:P0[:b/0<30`05EEE@020;:b/P0508>3P`2>SXh0/[:b0;6a/@0[:b/0o`0000010000000300l?3`00
000000000=X00000000:0000000=0:RXZ03oool0i>CT0<C4a03oool0`l?30?KfmP3Ogml0clo?0?oo
o`3IfMT00@4109jNWP020?ooo`0A09fMW@000000000002`/;03lo?`0oooo0>k^kP0P8200jn_[0?oo
o`3no_h0oOgm0?ooo`3moOd0_Kfm01DE5@1jNWX00P3oool02P2GUiL000000000000<30`0lO7a0?oo
o`3hn?P07QhN0000002j^[X20?ooo`0?06m_K`1JFUX0oooo0?KfmP2l_;`0oooo0<o?c`3UiND0kno_
0;no_`3oool0o?cl02`/;0000000^;Rh0080oooo0P1EEED20?ooo`080;Fe]@0000007alO0?[jnP3o
ool0m?Cd03Ti>@3Xj>P40?ooo`0K08F5Q@000000Lg=c0;:b/P2JVYX0YJFU0:n_[`2XZ:P0YJFU09>C
T`2b/[80P82000000012@T80/[:b0:n_[`0g=cL0WYjN0;:b/P1^KVh0000008:2PP2b/[80[:b/01<C
4`000000Ph>300D0/[:b00<0[jn_034a<@2@T900102b/[805@0J6QX0FEUI0;:b/P2UYJD0VYZJ0:n_
[`2XZ:P0ZZZZ08n?S`2b/[80Ti>C0000000];Bd0/[:b0;6a/@16ATH0QhN70;:b/P24Q8@0000005UI
F@020;:b/P0903/k>`000000Ph>30;:b/P2SXj<0BDU90;2`/02b/[80KFe]00<0000000P04A4A0:>S
X`2b/[80Hf=S069RHP2b/[80Z:RX00l?3ol000000@0000000`0?3`l000000000003J000000002@00
00001@0F5QH0k^k^0?ooo`2ZZZX0MGEe00<0oooo00H0Shn?08Z:RP3oool0o_kn03Xj>P1kNg/20?oo
o`040=3@d00O7al02`/;08:2PP80oooo00L0g=cL01TI6@3/k>`0oooo0>o_k`0c<c<0^k^k0080oooo
00D0IfMW06i^KP3oool0oooo09bLW0020000000700l?3`3`l?00oooo0?Shn00^;Rh0:RXZ0>7Qh@02
0?ooo`0605=CD`2a/K40oooo0>?Sh`1ADE40no_k0P3oool01`35aLD0HV9R0?ooo`3oool0PH610000
002g]kL00P3oool205EEE@80oooo00l0^KVi00`<301]KFd0o_kn0?ooo`3Kfm/08B4Q0>_[j`3oool0
o?cl0:BTY02DU9@0ATI600000010@4000`2b/[800`2@T900KVi^0;:b/P020;:b/P0D0820P0000000
1@D509FEU@2b/[80Q8B40:FUY@2b/[80D51@00820P1YJFT0/[:b0;6a/@0b<S800@4106][J`2b/[80
/K6a0:FUY@2WYjL20;:b/P0804A4A01eMGD0/[:b0;6a/@1gMgL0IFEU01@D500X:2P30;:b/P0309nO
W`1RHV80/[:b0080/[:b0240Ti>C00<30`000000Q8B40;:b/P2;Rh/0W9bL0;:b/P1SHf<00`<304=3
@`2a/K40/[:b05QHF0020P80JFUY0;:b/P2^[Zh0@41009jNWP2b/[80VIVI01TI6@0000008B4Q0000
001IFET0/[:b0:6QX@28R8P0/[:b08Z:RP010@40o`0000010000000300l?3`00000000000=X00000
00090000000605eMG@3oool0oooo0820P00/;2`0o_kn0P3oool01`1HF5P0E5AD0?ooo`3oool0YZJV
01`L703bl_800P3oool00`3Vi^H0c/k>0?ooo`020?ooo`0708R8R0051@D0kno_0?ooo`3emOD0MgMg
0=GEe@020?ooo`05065QH@1_Kfl0oooo0?ooo`2LW9`00P0000001P0?3`l0l?3`0?ooo`3moOd0d=3@
0>g]k@80oooo00L0fm_K03De=@3alO40oooo0;jn_P0>3Ph0hN7Q0080oooo00L0V9RH020P803inOT0
oooo0=oOg`0<30`0/k>c0080oooo0P1EEED20?ooo`030>k^kP3@d=00oooo0080oooo00/0RXZ:00<3
0`3_knl0oooo0?_kn`29RHT0Lg=c059BDP0000004Q8B0:JVYP020;:b/P030820P00S8b<0[Jf]0080
/[:b00@0P820000000000000B4Q80`2b/[80102`/;00?Cdm07MgM`2IVIT20;:b/P0;09ZJVP1aLG40
Fe]K0;:b/P2_[jl0;bl_02@T902][Jd0/[:b05ADE01LG5`00P2b/[801@1YJFT0D51@03Hf=P061PH0
V9RH0080/[:b00<0UYJF01TI6@2SXj<00P2b/[80102CTi<01@D50000000d=3@40;:b/P0804E5A@1J
FUX0TI6A0;6a/@2b/[80XZ:R07emO@1fMWH20;:b/P0>0410@01ADE40/[:b0;:b/P2MWId0O7al0:2P
X00E5AD03Ph>0:FUY@2b/[80/K6a0;:b/P1]KFgo00000080000000<03`l?000000000000fP000000
00P0000000L020P80=?Cd`3oool0oooo05YJFP010@40jNWY0080oooo00P0;Bd]02HV9P3oool0oooo
0?knoP0N7Qh0Fe]K0?7al@D0oooo00@0/;2`010@400;2`/0no_k1@3oool00`3Cdm<04Q8B0820P002
0?ooo`050:>SX`0000000000010@403kno/01@3oool00`3Lg=`0?clo092@T0020?ooo`0309NGU`00
0000[jn_0080oooo00<0K6a/0000003Ogml00P3oool0101LG5`0/k>c0?ooo`3oool205UIF@H0oooo
00@0];Bd01LG5`0:2PX0no_k103oool01038b<P0000000000021PH420;:b/P0307]kN`000000Ogmo
0080/[:b00D0QhN700000000000020P809fMW@020;:b/P030:n_[`0J6QX0Vi^K00D0/[:b00T0Fe]K
0;:b/P2b/[80=cLg0000002SXj<0/[:b071`L01=CDd0102b/[800`2GUiL0000006YZJP020;:b/P03
092@T0000000JFUY0080/[:b00D0VYZJ00D51@0000000@4108Z:RP030;:b/P03028R8P1^KVh0/[:b
00@0/[:b00H0QHF50;:b/P2b/[80HF5Q00<30`1eMGD40;:b/P0302l_;`000000H61P00<0/[:b00<0
DU9B000000000000o`0000000`0?3`l000000000003J00000000200000006P0K6a/0/[:b0;Jf]P2a
/K409BDU0000001cLg<0^[Zj0:>SX`061PH00P8209JFUP2g]kL0^[Zj04=3@`000000<c<c08n?S`31
`L40d=3@0:JVYP1PH60010@40000000;2`/0ZZZZ0P2e]KD02@2g]kL0ZZZZ07moO`0O7al0000005]K
F`2i^KT0^;Rh06i^KP020000000H00/;2`2ZZZX0]KFe0;Fe]@2c/k<0V9RH06UYJ@0J6QX0000009BD
U02f][H0]kNg04e=C@000000BTY:0;Jf]P2c/k<0:b/[0000001^KVh0^KVi0;Ng]`1[Jf/0NGUi0P2g
]kL203`l?00:0;Ng]`2e]KD0][Jf0:^[Z`2<S8`0CTi>00<30`0000002`/;0:ZZZP<0]KFe00D0^;Rh
08>3P`000000000003`l?0020820P00604a<C0000000;bl_07inOP20P800Fe]K0`0000001`16ATH0
P8200820P01/K6`00`<305UIF@20P8000`1nOWh02P1jNWX0?clo07MgM`21PH40=cLg0000001PH600
PH6105aLG00[:b/307inOP0=07moO`1cLg<00@4102d];@1nOWh0P82005YJFP0000008B4Q07emO@20
P800J6QX00<30`0200000007030`<01nOWh0Ogmo07MgM`030`<0?3`l0861P@0307inOP0B0820P01H
F5P0LW9b0820P01BDU80000000410@12@T80Ng]k09>CT`20P8008B4Q0000000E5AD0Ng]k07moO`1n
OWh09bLWo`0000020000000300/;2`00000000000=X00000001X0000000301hN7P0?3`l03`l?0?l0
3`l?@@0?3`l00`0N7Qh000000000003J00000000o`00003o000008X00000003o00000?l00000RP00
00000?l00000o`00002:00000000\
\>"], "WWMCHeader",
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    CellFrameMargins->4,
    ImageSize->{648, 25},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook", "Presentation"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellBracketOptions->{"Color"->RGBColor[0.66717, 0.187915, 0.232395]},
    CellElementSpacings->{"ClosedGroupTopMargin"->20},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    Background->RGBColor[0.924025, 0.891524, 0.771649]],
  
  Cell[StyleData["Notebook", "Printout"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellElementSpacings->{"ClosedGroupTopMargin"->20},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{40, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    ShowCellBracket->False,
    CellMargins->{{0, 100}, {0, 0}},
    CellFrameMargins->{{30, 100}, {10, 20}},
    AutoIndent->False,
    LineSpacing->{0, 44},
    FontSize->40,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.812512, 0, 0]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{10, 10}, {12, 30}},
    CellFrameMargins->2,
    FontSize->26]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{40, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    ShowCellBracket->False,
    CellMargins->{{98, 0}, {20, 0}},
    CellFrameMargins->{{10, 4}, {4, 6}},
    AutoIndent->False,
    LineSpacing->{0, 34},
    FontSize->30,
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{40, 10}, {1, 0}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{100, Inherited}, {20, 0}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellFrame->{{0, 0}, {2, 0}},
    ShowCellBracket->False,
    CellMargins->{{98, 0}, {60, 10}},
    CellFrameMargins->{{4, 4}, {2, 8}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{40, 10}, {60, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->None,
    CellMargins->{{40, 22}, {0, 30}},
    CellFrameMargins->{{99, 0}, {1, 4}},
    CellFrameColor->RGBColor[0.708598, 0.00158694, 0.047715],
    CellFrameLabelMargins->{{4, 4}, {0, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{10, 0}, {4, 22}},
    CellFrameMargins->3,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{40, 22}, {0, 30}},
    CellFrameMargins->{{0, 0}, {0, 2}},
    CellFrameColor->GrayLevel[1],
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 0}, {0, 22}},
    CellFrameMargins->3,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{99, 60}, {0, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{40, 0}, {0, 25}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{99, 22}, {10, 10}},
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 3},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{40, 2}, {6, 6}},
    TextJustification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{119, 22}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->12,
    FontColor->RGBColor[0.0899214, 0.182635, 0.460777]],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{50, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{12, 10}, {2, 2}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Item", "Presentation"],
    CellMargins->{{99, 22}, {4, 4}},
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 3},
    FontSize->16],
  
  Cell[StyleData["Item", "Condensed"],
    CellMargins->{{8, 10}, {1, 1}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Item", "Printout"],
    CellMargins->{{40, 2}, {2, 2}},
    TextJustification->0.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{99, 45}, {0, 10}},
    CellFrameMargins->12,
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.28748, 0.378042, 0.556527],
    ButtonBoxOptions->{ButtonMinHeight->0.125,
    ButtonMargins->9,
    Background->RGBColor[0.665293, 0.0723888, 0.101137]}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->True,
    CellMargins->{{40, 0}, {0, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9,
    Background->GrayLevel[0.849989]]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{99, Inherited}, {Inherited, Inherited}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputWord"],
    CellMargins->{{99, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"InputGrouping",
    AutoItalicWords->{},
    FormatType->InputForm,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{99, 45}, {10, 0}},
    CellFrameMargins->12,
    LineSpacing->{1, 0},
    FontSize->16,
    Background->RGBColor[0.978958, 0.959915, 0.622477]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellFrame->True,
    CellMargins->{{40, 0}, {6, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{99, 45}, {Inherited, Inherited}},
    CellFrameMargins->12,
    LineSpacing->{1, 0},
    FontColor->RGBColor[0.694072, 0.204471, 0.227802],
    Background->RGBColor[0.963821, 0.948333, 0.891249]],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{40, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{99, 45}, {0, 0}},
    CellFrameMargins->{{12, 12}, {2, 2}},
    LineSpacing->{1, 0},
    Background->GrayLevel[1]],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{99, 45}, {10, 0}},
    Background->GrayLevel[1]],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    CellFrame->True,
    CellMargins->{{40, 0}, {0, -1}},
    ImageMargins->{{40, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{99, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{10, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{99, Inherited}, {Inherited, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Expression Annotation Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to effect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to
make them stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Examples"->{
    Cell[67953, 1128, 71, 1, 46, "Subsection",
      CellTags->"Examples"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Examples", 150159, 3154}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 47, 0, 118, "Title"],
Cell[1781, 53, 303, 10, 112, "Subtitle"],
Cell[2087, 65, 163, 4, 130, "Author"],

Cell[CellGroupData[{
Cell[2275, 73, 37, 0, 65, "Section"],

Cell[CellGroupData[{
Cell[2337, 77, 30, 0, 56, "Subsection"],
Cell[2370, 79, 318, 7, 100, "Text"],
Cell[2691, 88, 38, 0, 28, "Item"],
Cell[2732, 90, 50, 0, 28, "Item"],
Cell[2785, 92, 183, 4, 68, "Item"],
Cell[2971, 98, 359, 6, 120, "Text"],
Cell[3333, 106, 419, 9, 120, "Text"],
Cell[3755, 117, 202, 4, 80, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3994, 126, 79, 0, 46, "Subsection"],
Cell[4076, 128, 476, 12, 120, "Text"],
Cell[4555, 142, 127, 4, 40, "Text"],
Cell[4685, 148, 4814, 63, 40, 4701, 59, "GraphicsData", "Bitmap", "Graphics",
  Evaluatable->False],
Cell[9502, 213, 116, 4, 40, "Text"],
Cell[9621, 219, 48351, 600, 250, 48259, 597, "GraphicsData", 
"Bitmap", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[58009, 824, 51, 0, 46, "Subsection"],
Cell[58063, 826, 192, 5, 34, "Item",
  CounterAssignments->{{"ItemizedText", 0}}],
Cell[58258, 833, 96, 3, 28, "Item"],
Cell[58357, 838, 167, 6, 48, "Item"],
Cell[58527, 846, 236, 5, 100, "Text"],
Cell[58766, 853, 281, 5, 100, "Text"],
Cell[59050, 860, 290, 6, 100, "Text"],
Cell[59343, 868, 242, 5, 80, "Text"],
Cell[59588, 875, 418, 7, 120, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[60043, 887, 33, 0, 46, "Subsection"],
Cell[60079, 889, 281, 5, 100, "Text"],
Cell[60363, 896, 295, 5, 88, "Item"],
Cell[60661, 903, 154, 4, 44, "Text"],
Cell[60818, 909, 1003, 21, 228, "Item"],
Cell[61824, 932, 320, 7, 100, "Text"],
Cell[62147, 941, 400, 7, 108, "Item"],
Cell[62550, 950, 985, 19, 228, "Item"],
Cell[63538, 971, 241, 5, 68, "Item"]
}, Closed]],

Cell[CellGroupData[{
Cell[63816, 981, 37, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[63878, 985, 36, 0, 47, "Subsubsection"],
Cell[63917, 987, 239, 7, 40, "Text"],
Cell[64159, 996, 477, 11, 140, "Text"],
Cell[64639, 1009, 315, 8, 80, "Text"],
Cell[64957, 1019, 194, 6, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[65188, 1030, 52, 0, 41, "Subsubsection"],
Cell[65243, 1032, 254, 8, 40, "Text"],
Cell[65500, 1042, 310, 5, 120, "Text"],
Cell[65813, 1049, 349, 6, 120, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[66199, 1060, 44, 0, 41, "Subsubsection"],
Cell[66246, 1062, 239, 7, 40, "Text"],
Cell[66488, 1071, 271, 5, 100, "Text"],
Cell[66762, 1078, 141, 4, 28, "Item"],
Cell[66906, 1084, 416, 17, 68, "Item"],
Cell[67325, 1103, 283, 8, 68, "Item"]
}, Closed]],

Cell[CellGroupData[{
Cell[67645, 1116, 55, 0, 41, "Subsubsection"],
Cell[67703, 1118, 201, 4, 80, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[67953, 1128, 71, 1, 46, "Subsection",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[68049, 1133, 39, 0, 47, "Subsubsection"],
Cell[68091, 1135, 434, 10, 80, "Text"],
Cell[68528, 1147, 185, 5, 84, "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68750, 1157, 47, 0, 47, "Subsubsection"],
Cell[68800, 1159, 274, 8, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69111, 1172, 43, 0, 47, "Subsubsection"],
Cell[69157, 1174, 220, 7, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69414, 1186, 51, 0, 47, "Subsubsection"],
Cell[69468, 1188, 222, 7, 40, "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[69751, 1202, 43, 0, 55, "Section"],
Cell[69797, 1204, 318, 9, 36, "Item"],
Cell[70118, 1215, 330, 9, 48, "Item"],
Cell[70451, 1226, 157, 4, 48, "Item"],
Cell[70611, 1232, 24847, 311, 138, 24708, 306, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[95461, 1545, 727, 19, 280, "Text"],
Cell[96191, 1566, 328, 6, 100, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[96556, 1577, 34, 0, 55, "Section"],

Cell[CellGroupData[{
Cell[96615, 1581, 50, 0, 56, "Subsection"],
Cell[96668, 1583, 406, 12, 100, "Text"],
Cell[97077, 1597, 191, 4, 40, "Text"],
Cell[97271, 1603, 1443, 48, 160, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[98751, 1656, 35, 0, 46, "Subsection"],
Cell[98789, 1658, 379, 5, 120, "Text"],
Cell[99171, 1665, 56, 0, 40, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[99264, 1670, 44, 0, 46, "Subsection"],
Cell[99311, 1672, 118, 3, 60, "Text"],
Cell[99432, 1677, 56, 0, 40, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[99525, 1682, 39, 0, 46, "Subsection"],
Cell[99567, 1684, 176, 4, 80, "Text"],
Cell[99746, 1690, 56, 0, 40, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[99851, 1696, 94, 2, 55, "Section"],
Cell[99948, 1700, 109, 4, 68, "Subsubsection"],

Cell[CellGroupData[{
Cell[100082, 1708, 57, 1, 56, "Subsection"],
Cell[100142, 1711, 327, 8, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100506, 1724, 44, 0, 56, "Subsection"],
Cell[100553, 1726, 193, 6, 60, "Text"],

Cell[CellGroupData[{
Cell[100771, 1736, 72, 1, 47, "Subsubsection"],
Cell[100846, 1739, 449, 6, 220, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[101344, 1751, 87, 1, 56, "Subsection"],
Cell[101434, 1754, 534, 17, 160, "Text"]
}, Open  ]],
Cell[101983, 1774, 139, 5, 56, "Subsection"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

