(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     31780,       1305]*)
(*NotebookOutlinePosition[     32620,       1332]*)
(*  CellTagsIndexPosition[     32576,       1328]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Keyboard Shortcuts Styles", "Section"],

Cell[CellGroupData[{

Cell["Default", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Head1"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{12, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CounterIncrements->"Head1",
  CounterAssignments->{{"Head2", 0}, {"Head3", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Head1", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Head2"],
  CellMargins->{{12, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Head2",
  CounterAssignments->{{"Head3", 0}},
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Head2", "Printout"],
  CellMargins->{{9, 0}, {7, 22}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Head3"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Head3",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Head3", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{45, Inherited}, {7, 7}},
  CellHorizontalScrolling->True,
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{45, 10}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{39, 55}, {0, 10}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["User Defined", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Custom1"]],

Cell[StyleData["Custom1", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Custom2"]],

Cell[StyleData["Custom2", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Custom3"]],

Cell[StyleData["Custom3", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  CounterIncrements->"SmallText",
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item1"],
  CellMargins->{{48, 4}, {4, 4}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  ParagraphIndent->-23,
  CounterIncrements->"Item1",
  StyleMenuListing->None],

Cell[StyleData["Item1", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item1Continued"],
  CellMargins->{{71, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Item1Continued",
  StyleMenuListing->None],

Cell[StyleData["Item1Continued", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item2"],
  CellMargins->{{71, 4}, {3, 3}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  ParagraphIndent->-21,
  CounterIncrements->"Item2Continued",
  StyleMenuListing->None],

Cell[StyleData["Item2", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item2Continued"],
  CellMargins->{{92, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Item2Continued",
  StyleMenuListing->None],

Cell[StyleData["Item2Continued", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item3"],
  CellMargins->{{94, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  ParagraphIndent->-23,
  CounterIncrements->"Item3Continued",
  StyleMenuListing->None],

Cell[StyleData["Item3", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item3Continued"],
  CellMargins->{{117, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Item3Continued",
  StyleMenuListing->None],

Cell[StyleData["Item3Continued", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ScriptLevel->1,
  SingleLetterItalics->True],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{2, 0}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{12, Inherited}, {7, 7}},
  CellFrameMargins->{{0, 0}, {7, 5}},
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Lemma"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Lemma"],

Cell[StyleData["Lemma", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Theorem"],

Cell[StyleData["Theorem", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Figure"],
  CellMargins->{{12, 4}, {0, 2}},
  PageBreakAbove->False,
  CounterIncrements->"Figure",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Figure", "Printout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableHead"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"TableHead"],

Cell[StyleData["TableHead", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Reference"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Reference"],

Cell[StyleData["Reference", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{12, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{12, 4}, {0, 2}},
  PageBreakAbove->False,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ChapterNumber"],
  CellMargins->{{12, Inherited}, {20, 60}},
  CellGroupingRules->{"SectionGrouping", 0},
  PageBreakAbove->True,
  CounterIncrements->"SectionNumber",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {
      "NumberedEquation", 0}},
  FontFamily->"Times",
  FontSize->18],

Cell[StyleData["ChapterNumber", "Printout"],
  CellMargins->{{2, 0}, {10, 30}},
  FontSize->15]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}, {"Head1", 0}},
  FontFamily->"Times",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {12, 30}},
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Times",
  FontSize->24,
  FontSlant->"Italic"],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserTips"],
  CellFrame->{{0, 0}, {0.5, 2}},
  CellMargins->{{12, 4}, {2, 20}},
  CellFrameColor->RGBColor[0, 0, 0.8],
  LineSpacing->{1, 3},
  ParagraphIndent->-33,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["UserTips", "Printout"],
  CellMargins->{{2, 0}, {0, 4}},
  LineSpacing->{1, 3},
  FontSize->8,
  Background->GrayLevel[0.700008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserTipsList"],
  CellFrame->{{0, 0}, {0.5, 2}},
  CellMargins->{{12, 4}, {2, 20}},
  CellFrameColor->RGBColor[0, 0, 0.8],
  LineSpacing->{1, 3},
  ParagraphIndent->-7,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["UserTipsList", "Printout"],
  CellMargins->{{2, 0}, {0, 4}},
  LineSpacing->{1, 3},
  FontSize->8,
  Background->GrayLevel[0.700008]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "UserGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["UserGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ReferenceLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["ReferenceLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SamplesLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Samples", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["SamplesLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserDocsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "UserDocs", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["UserDocsLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Outline Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Outline1"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  ParagraphIndent->-38,
  CounterIncrements->"Outline1",
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral},
  StyleMenuListing->None,
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Outline1", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline2"],
  CellMargins->{{59, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  ParagraphIndent->-27,
  CounterIncrements->"Outline2",
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)},
  StyleMenuListing->None,
  FontSize->15,
  FontWeight->"Bold"],

Cell[StyleData["Outline2", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline3"],
  CellMargins->{{108, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  ParagraphIndent->-21,
  CounterIncrements->"Outline3",
  CounterBoxOptions->{CounterFunction:>Identity},
  StyleMenuListing->None,
  FontSize->12],

Cell[StyleData["Outline3", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline4"],
  CellMargins->{{158, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  ParagraphIndent->-18,
  CounterIncrements->"Outline4",
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "a", "z"], #]&)},
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["Outline4", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Conformance Styles", "Section"],

Cell[CellGroupData[{

Cell["Backward Compatible Text Styles", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{20, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"ItemizedText"],

Cell[StyleData["ItemizedText", "Printout"],
  ParagraphIndent->-18,
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{41, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedPicture"],
  CellMargins->{{41, Inherited}, {4, 4}},
  CellHorizontalScrolling->True],

Cell[StyleData["ItemizedPicture", "Printout"],
  CellMargins->{{38, 4}, {8, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{20, 4}, {0, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Text"],

Cell[StyleData["IndentedText", "Printout"],
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{46, 42}, {0, 14}},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Backward Compatible Headings Styles", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->None,
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 22}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->11]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Subsection"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[StyleData["InputOnly"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  StyleMenuListing->None],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  FontSize->9,
  Magnification->0.8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["System Styles", "Section"],

Cell[CellGroupData[{

Cell["FormatType Styles", "Subsection"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Subsection"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Subsection"],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["Placeholder", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->Primary,
  StyleMenuListing->None,
  DrawHighlighted->True],

Cell[StyleData["SelectionPlaceholder", "Printout"]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{499, 460},
WindowMargins->{{17, Automatic}, {Automatic, 0}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 62, "Subtitle"],
Cell[1771, 53, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1989, 61, 42, 0, 50, "Section"],
Cell[2034, 63, 77, 2, 36, 31, 0, "StyleData", "All", "Working"],
Cell[2114, 67, 140, 4, 34, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2291, 76, 35, 0, 30, "Section"],
Cell[2329, 78, 101, 3, 30, "Text"],
Cell[2433, 83, 426, 11, 36, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[2896, 99, 44, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[2965, 103, 29, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[3019, 107, 318, 9, 77, 24, 0, "StyleData", "Head1", "All",
  CounterIncrements->"Head1",
  CounterAssignments->{{"Head2", 0}, {"Head3", 0}}],
Cell[3340, 118, 87, 2, 69, 36, 0, "StyleData", "Head1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3464, 125, 244, 7, 44, 24, 0, "StyleData", "Head2", "All",
  CounterIncrements->"Head2",
  CounterAssignments->{{"Head3", 0}}],
Cell[3711, 134, 86, 2, 61, 36, 0, "StyleData", "Head2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3834, 141, 245, 7, 44, 24, 0, "StyleData", "Head3", "All",
  CounterIncrements->"Head3"],
Cell[4082, 150, 86, 2, 51, 36, 0, "StyleData", "Head3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4205, 157, 110, 3, 39, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[4318, 162, 68, 1, 40, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4423, 168, 211, 5, 39, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[4637, 175, 45, 0, 42, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4719, 180, 318, 7, 39, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[5040, 189, 99, 2, 37, 47, 0, "StyleData", "NumberedEquation", 
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5188, 197, 34, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[5247, 201, 26, 0, 36, 26, 0, "StyleData", "Custom1", "All"],
Cell[5276, 203, 71, 1, 40, 38, 0, "StyleData", "Custom1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5384, 209, 26, 0, 36, 26, 0, "StyleData", "Custom2", "All"],
Cell[5413, 211, 71, 1, 40, 38, 0, "StyleData", "Custom2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5521, 217, 26, 0, 36, 26, 0, "StyleData", "Custom3", "All"],
Cell[5550, 219, 71, 1, 40, 38, 0, "StyleData", "Custom3", "Printout"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5682, 227, 28, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[5735, 231, 188, 6, 38, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText",
  StyleMenuListing->None],
Cell[5926, 239, 88, 2, 33, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6051, 246, 212, 6, 36, 24, 0, "StyleData", "Item1", "All",
  CounterIncrements->"Item1",
  StyleMenuListing->None],
Cell[6266, 254, 70, 1, 36, 36, 0, "StyleData", "Item1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6373, 260, 206, 5, 34, 33, 0, "StyleData", "Item1Continued", "All",
  CounterIncrements->"Item1Continued",
  StyleMenuListing->None],
Cell[6582, 267, 79, 1, 36, 45, 0, "StyleData", "Item1Continued", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6698, 273, 221, 6, 35, 24, 0, "StyleData", "Item2", "All",
  CounterIncrements->"Item2Continued",
  StyleMenuListing->None],
Cell[6922, 281, 70, 1, 32, 36, 0, "StyleData", "Item2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7029, 287, 206, 5, 34, 33, 0, "StyleData", "Item2Continued", "All",
  CounterIncrements->"Item2Continued",
  StyleMenuListing->None],
Cell[7238, 294, 79, 1, 32, 45, 0, "StyleData", "Item2Continued", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7354, 300, 221, 6, 34, 24, 0, "StyleData", "Item3", "All",
  CounterIncrements->"Item3Continued",
  StyleMenuListing->None],
Cell[7578, 308, 70, 1, 32, 36, 0, "StyleData", "Item3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7685, 314, 207, 5, 34, 33, 0, "StyleData", "Item3Continued", "All",
  CounterIncrements->"Item3Continued",
  StyleMenuListing->None],
Cell[7895, 321, 79, 1, 32, 45, 0, "StyleData", "Item3Continued", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8023, 328, 43, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[8091, 332, 146, 4, 36, 32, 0, "StyleData", "InlineFormula", "All"],
Cell[8240, 338, 77, 1, 40, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8354, 344, 166, 4, 52, 26, 0, "StyleData", "Program", "All"],
Cell[8523, 350, 98, 2, 51, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8670, 358, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[8734, 362, 112, 3, 42, 24, 0, "StyleData", "Lemma", "All",
  CounterIncrements->"Lemma"],
Cell[8849, 367, 69, 1, 40, 36, 0, "StyleData", "Lemma", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8955, 373, 116, 3, 39, 26, 0, "StyleData", "Theorem", "All",
  CounterIncrements->"Theorem"],
Cell[9074, 378, 71, 1, 40, 38, 0, "StyleData", "Theorem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9182, 384, 157, 5, 30, 25, 0, "StyleData", "Figure", "All",
  CounterIncrements->"Figure"],
Cell[9342, 391, 85, 2, 29, 37, 0, "StyleData", "Figure", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9464, 398, 120, 3, 39, 28, 0, "StyleData", "TableHead", "All",
  CounterIncrements->"TableHead"],
Cell[9587, 403, 73, 1, 40, 40, 0, "StyleData", "TableHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9697, 409, 120, 3, 39, 28, 0, "StyleData", "Reference", "All",
  CounterIncrements->"Reference"],
Cell[9820, 414, 73, 1, 40, 40, 0, "StyleData", "Reference", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9930, 420, 101, 2, 32, 26, 0, "StyleData", "Picture", "All"],
Cell[10034, 424, 79, 1, 36, 38, 0, "StyleData", "Picture", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10150, 430, 127, 4, 30, 26, 0, "StyleData", "Caption", "All"],
Cell[10280, 436, 86, 2, 29, 38, 0, "StyleData", "Caption", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10403, 443, 310, 8, 58, 32, 0, "StyleData", "ChapterNumber", "All",
  CounterIncrements->"SectionNumber",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {
      "NumberedEquation", 0}}],
Cell[10716, 453, 95, 2, 71, 44, 0, "StyleData", "ChapterNumber", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10848, 460, 357, 9, 76, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}, {"Head1", 0}}],
Cell[11208, 471, 88, 2, 86, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11333, 478, 334, 9, 67, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[11670, 489, 90, 2, 56, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11797, 496, 443, 13, 54, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[12243, 511, 93, 2, 50, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12373, 518, 250, 8, 51, 27, 0, "StyleData", "UserTips", "All",
  StyleMenuListing->None],
Cell[12626, 528, 145, 4, 46, 39, 0, "StyleData", "UserTips", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12808, 537, 253, 8, 51, 31, 0, "StyleData", "UserTipsList", "All",
  StyleMenuListing->None],
Cell[13064, 547, 149, 4, 46, 43, 0, "StyleData", "UserTipsList", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13262, 557, 36, 0, 30, "Section"],
Cell[13301, 559, 121, 3, 46, "Text"],
Cell[13425, 564, 92, 3, 36, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[13520, 569, 69, 2, 38, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[13592, 573, 70, 2, 38, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[13665, 577, 115, 4, 36, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[13783, 583, 116, 4, 38, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[13902, 589, 114, 4, 38, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[14019, 595, 116, 4, 38, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[14138, 601, 117, 4, 36, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[14258, 607, 118, 4, 37, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[14379, 613, 116, 4, 37, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[14498, 619, 118, 4, 37, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[14619, 625, 119, 4, 37, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[14741, 631, 120, 4, 38, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[14864, 637, 118, 4, 38, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[14985, 643, 120, 4, 38, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[15142, 652, 35, 0, 30, "Section"],
Cell[15180, 654, 184, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[15389, 662, 302, 8, 36, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[15694, 672, 107, 2, 36, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[15816, 677, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[15945, 684, 328, 8, 36, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16276, 694, 116, 2, 36, 49, 0, "StyleData", "GettingStartedLink", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16429, 701, 318, 8, 36, 32, 0, "StyleData", "UserGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16750, 711, 111, 2, 36, 44, 0, "StyleData", "UserGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16898, 718, 325, 8, 36, 32, 0, "StyleData", "ReferenceLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17226, 728, 111, 2, 36, 44, 0, "StyleData", "ReferenceLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17374, 735, 314, 8, 36, 30, 0, "StyleData", "SamplesLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17691, 745, 109, 2, 36, 42, 0, "StyleData", "SamplesLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17837, 752, 316, 8, 36, 31, 0, "StyleData", "UserDocsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[18156, 762, 110, 2, 36, 43, 0, "StyleData", "UserDocsLink", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18315, 770, 33, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[18373, 774, 290, 8, 51, 27, 0, "StyleData", "Outline1", "All",
  CounterIncrements->"Outline1",
  StyleMenuListing->None],
Cell[18666, 784, 39, 0, 51, 39, 0, "StyleData", "Outline1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18742, 789, 316, 9, 42, 27, 0, "StyleData", "Outline2", "All",
  CounterIncrements->"Outline2",
  StyleMenuListing->None],
Cell[19061, 800, 39, 0, 45, 39, 0, "StyleData", "Outline2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19137, 805, 258, 7, 39, 27, 0, "StyleData", "Outline3", "All",
  CounterIncrements->"Outline3",
  StyleMenuListing->None],
Cell[19398, 814, 39, 0, 42, 39, 0, "StyleData", "Outline3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19474, 819, 295, 8, 38, 27, 0, "StyleData", "Outline4", "All",
  CounterIncrements->"Outline4",
  StyleMenuListing->None],
Cell[19772, 829, 39, 0, 41, 39, 0, "StyleData", "Outline4", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19860, 835, 49, 0, 30, "Section"],
Cell[19912, 837, 123, 4, 32, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[20038, 843, 122, 4, 30, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[20163, 849, 127, 4, 32, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[20327, 858, 37, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[20389, 862, 53, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[20467, 866, 177, 5, 32, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"ItemizedText"],
Cell[20647, 873, 83, 2, 31, 43, 0, "StyleData", "ItemizedText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20767, 880, 149, 4, 32, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text"],
Cell[20919, 886, 97, 2, 31, 47, 0, "StyleData", "ItemizedTextNote", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21053, 893, 109, 2, 36, 34, 0, "StyleData", "ItemizedPicture", "All"],
Cell[21165, 897, 80, 1, 44, 46, 0, "StyleData", "ItemizedPicture", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21282, 903, 145, 4, 32, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text"],
Cell[21430, 909, 59, 1, 33, 43, 0, "StyleData", "IndentedText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21526, 915, 215, 6, 32, 30, 0, "StyleData", "MathCaption", "All"],
Cell[21744, 923, 121, 3, 41, 42, 0, "StyleData", "MathCaption", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21914, 932, 57, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[21996, 936, 362, 10, 64, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[22361, 948, 89, 2, 61, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22487, 955, 327, 9, 44, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[22817, 966, 91, 2, 59, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22945, 973, 271, 7, 42, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection",
  StyleMenuListing->None],
Cell[23219, 982, 94, 2, 48, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23362, 990, 45, 0, 30, "Subsection"],
Cell[23410, 992, 364, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[23799, 1002, 460, 14, 42, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],
Cell[24262, 1018, 85, 2, 36, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],
Cell[24362, 1023, 309, 10, 38, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[24696, 1037, 480, 14, 40, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output",
  StyleMenuListing->None],
Cell[25179, 1053, 86, 2, 36, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25302, 1060, 501, 14, 36, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[25806, 1076, 138, 3, 32, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25981, 1084, 465, 13, 36, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[26449, 1099, 109, 2, 32, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26595, 1106, 439, 12, 36, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[27037, 1120, 127, 3, 29, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27201, 1128, 128, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[27332, 1134, 130, 4, 32, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27523, 1145, 32, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[27580, 1149, 39, 0, 46, "Subsection"],
Cell[27622, 1151, 305, 5, 62, "Text"],
Cell[27930, 1158, 314, 10, 36, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[28247, 1170, 106, 3, 36, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[28356, 1175, 151, 5, 36, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[28510, 1182, 108, 3, 36, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[28621, 1187, 179, 5, 36, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[28803, 1194, 115, 3, 30, "Text"],
Cell[28921, 1199, 96, 3, 36, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[29020, 1204, 104, 2, 52, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[29161, 1211, 36, 0, 30, "Subsection"],
Cell[29200, 1213, 121, 3, 30, "Text"],
Cell[29324, 1218, 226, 5, 36, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29553, 1225, 295, 7, 36, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29851, 1234, 400, 9, 36, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30254, 1245, 387, 9, 36, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30644, 1256, 401, 9, 36, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[31082, 1270, 40, 0, 30, "Subsection"],
Cell[31125, 1272, 115, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[31265, 1279, 145, 5, 36, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[31413, 1286, 42, 0, 36, 42, 0, "StyleData", "Placeholder", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31492, 1291, 182, 6, 36, 39, 0, "StyleData", "SelectionPlaceholder", 
"All",
  StyleMenuListing->None],
Cell[31677, 1299, 51, 0, 36, 51, 0, "StyleData", "SelectionPlaceholder", 
"Printout"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

